@@ -5,12 +5,12 @@ import click
 import dagster._check as check
 import dagster._seven as seven
 import requests
+from dagster._cli.utils import get_instance_for_cli, get_temporary_instance_for_cli
 from dagster._cli.workspace import workspace_target_argument
 from dagster._cli.workspace.cli_target import (
     WORKSPACE_TARGET_WARNING,
     get_workspace_process_context_from_kwargs,
 )
-from dagster._core.instance import DagsterInstance
 from dagster._core.workspace.context import WorkspaceProcessContext
 from dagster._utils import DEFAULT_WORKSPACE_YAML_FILENAME
 from dagster._utils.log import get_stack_trace_array
@@ -196,16 +196,18 @@ def ui(text, file, predefined, variables, remote, output, ephemeral_instance, **
         res = execute_query_against_remote(remote, query, variables)
         print(res)  # noqa: T201
     else:
-        instance = DagsterInstance.ephemeral() if ephemeral_instance else DagsterInstance.get()
-        with get_workspace_process_context_from_kwargs(
-            instance, version=__version__, read_only=False, kwargs=kwargs
-        ) as workspace_process_context:
-            execute_query_from_cli(
-                workspace_process_context,
-                query,
-                variables,
-                output,
-            )
+        with (
+            get_temporary_instance_for_cli() if ephemeral_instance else get_instance_for_cli()
+        ) as instance:
+            with get_workspace_process_context_from_kwargs(
+                instance, version=__version__, read_only=False, kwargs=kwargs
+            ) as workspace_process_context:
+                execute_query_from_cli(
+                    workspace_process_context,
+                    query,
+                    variables,
+                    output,
+                )
 
 
 cli = create_dagster_graphql_cli()
