@@ -1,10 +1,11 @@
 from itertools import chain
-from typing import Any, Dict, Iterable, List, Mapping, Optional
+from typing import Any, Dict, Iterable, List, Mapping, Optional, Sequence, Union
 
 import dagster._check as check
 import requests.exceptions
 from dagster import DagsterRunStatus
 from dagster._annotations import public
+from dagster._core.definitions.run_config import RunConfig, convert_config_input
 from dagster._core.definitions.utils import validate_tags
 from dagster._utils.backcompat import experimental_class_warning
 from gql import Client, gql
@@ -22,7 +23,7 @@ from .client_queries import (
 from .utils import (
     DagsterGraphQLClientError,
     InvalidOutputErrorInfo,
-    PipelineInfo,
+    JobInfo,
     ReloadRepositoryLocationInfo,
     ReloadRepositoryLocationStatus,
     ShutdownRepositoryLocationInfo,
@@ -102,15 +103,13 @@ class DagsterGraphQLClient:
                 f" \n{variables}\n"
             ) from exc
 
-    def _get_repo_locations_and_names_with_pipeline(self, pipeline_name: str) -> List[PipelineInfo]:
+    def _get_repo_locations_and_names_with_pipeline(self, job_name: str) -> List[JobInfo]:
         res_data = self._execute(CLIENT_GET_REPO_LOCATIONS_NAMES_AND_PIPELINES_QUERY)
         query_res = res_data["repositoriesOrError"]
         repo_connection_status = query_res["__typename"]
         if repo_connection_status == "RepositoryConnection":
-            valid_nodes: Iterable[PipelineInfo] = chain(
-                *map(PipelineInfo.from_node, query_res["nodes"])
-            )
-            return [info for info in valid_nodes if info.pipeline_name == pipeline_name]
+            valid_nodes: Iterable[JobInfo] = chain(*map(JobInfo.from_node, query_res["nodes"]))
+            return [info for info in valid_nodes if info.job_name == job_name]
         else:
             raise DagsterGraphQLClientError(repo_connection_status, query_res["message"])
 
@@ -119,11 +118,11 @@ class DagsterGraphQLClient:
         pipeline_name: str,
         repository_location_name: Optional[str] = None,
         repository_name: Optional[str] = None,
-        run_config: Optional[Mapping[str, Any]] = None,
-        mode: Optional[str] = None,
+        run_config: Optional[Union[RunConfig, Mapping[str, Any]]] = None,
+        mode: str = "default",
         preset: Optional[str] = None,
         tags: Optional[Mapping[str, str]] = None,
-        solid_selection: Optional[List[str]] = None,
+        op_selection: Optional[Sequence[str]] = None,
         is_using_job_op_graph_apis: Optional[bool] = False,
     ):
         check.opt_str_param(repository_location_name, "repository_location_name")
@@ -131,7 +130,7 @@ class DagsterGraphQLClient:
         check.str_param(pipeline_name, "pipeline_name")
         check.opt_str_param(mode, "mode")
         check.opt_str_param(preset, "preset")
-        run_config = check.opt_mapping_param(run_config, "run_config")
+        run_config = check.opt_mapping_param(convert_config_input(run_config), "run_config")
 
         # The following invariant will never fail when a job is executed
         check.invariant(
@@ -146,8 +145,8 @@ class DagsterGraphQLClient:
         pipeline_or_job = "Job" if is_using_job_op_graph_apis else "Pipeline"
 
         if not repository_location_name or not repository_name:
-            pipeline_info_lst = self._get_repo_locations_and_names_with_pipeline(pipeline_name)
-            if len(pipeline_info_lst) == 0:
+            job_info_lst = self._get_repo_locations_and_names_with_pipeline(pipeline_name)
+            if len(job_info_lst) == 0:
                 raise DagsterGraphQLClientError(
                     f"{pipeline_or_job}NotFoundError",
                     (
@@ -155,15 +154,15 @@ class DagsterGraphQLClient:
                         f" `{pipeline_name}` exist"
                     ),
                 )
-            elif len(pipeline_info_lst) == 1:
-                pipeline_info = pipeline_info_lst[0]
-                repository_location_name = pipeline_info.repository_location_name
-                repository_name = pipeline_info.repository_name
+            elif len(job_info_lst) == 1:
+                job_info = job_info_lst[0]
+                repository_location_name = job_info.repository_location_name
+                repository_name = job_info.repository_name
             else:
                 raise DagsterGraphQLClientError(
                     "Must specify repository_location_name and repository_name since there are"
                     f" multiple {'jobs' if is_using_job_op_graph_apis else 'pipelines'} with the"
-                    f" name {pipeline_name}.\n\tchoose one of: {pipeline_info_lst}"
+                    f" name {pipeline_name}.\n\tchoose one of: {job_info_lst}"
                 )
 
         variables: Dict[str, Any] = {
@@ -172,7 +171,7 @@ class DagsterGraphQLClient:
                     "repositoryLocationName": repository_location_name,
                     "repositoryName": repository_name,
                     "pipelineName": pipeline_name,
-                    "solidSelection": solid_selection,
+                    "solidSelection": op_selection,
                 }
             }
         }
@@ -214,67 +213,6 @@ class DagsterGraphQLClient:
             # a PipelineNotFoundError, a RunConflict, or a PythonError
             raise DagsterGraphQLClientError(query_result_type, query_result["message"])
 
-    def submit_pipeline_execution(
-        self,
-        pipeline_name: str,
-        repository_location_name: Optional[str] = None,
-        repository_name: Optional[str] = None,
-        run_config: Optional[Any] = None,
-        mode: Optional[str] = None,
-        preset: Optional[str] = None,
-        tags: Optional[Dict[str, Any]] = None,
-        solid_selection: Optional[List[str]] = None,
-    ) -> str:
-        """Submits a Pipeline with attached configuration for execution.
-
-        Args:
-            pipeline_name (str): The pipeline's name
-            repository_location_name (Optional[str], optional): The name of the repository location where
-                the pipeline is located. If omitted, the client will try to infer the repository location
-                from the available options on the Dagster deployment. Defaults to None.
-            repository_name (Optional[str], optional): The name of the repository where the pipeline is located.
-                If omitted, the client will try to infer the repository from the available options
-                on the Dagster deployment. Defaults to None.
-            run_config (Optional[Any], optional): This is the run config to execute the pipeline with.
-                Note that runConfigData is any-typed in the GraphQL type system. This type is used when passing in
-                an arbitrary object for run config. However, it must conform to the constraints of the config
-                schema for this pipeline. If it does not, the client will throw a DagsterGraphQLClientError with a message of
-                RunConfigValidationInvalid. Defaults to None.
-            mode (Optional[str], optional): The mode to run the pipeline with. If you have not
-                defined any custom modes for your pipeline, the default mode is "default". Defaults to None.
-            preset (Optional[str], optional): The name of a pre-defined preset to use instead of a
-                run config. Defaults to None.
-            tags (Optional[Dict[str, Any]], optional): A set of tags to add to the pipeline execution.
-
-        Raises:
-            DagsterGraphQLClientError("InvalidStepError", invalid_step_key): the pipeline has an invalid step
-            DagsterGraphQLClientError("InvalidOutputError", body=error_object): some solid has an invalid output within the pipeline.
-                The error_object is of type dagster_graphql.InvalidOutputErrorInfo.
-            DagsterGraphQLClientError("ConflictingExecutionParamsError", invalid_step_key): a preset and a run_config & mode are present
-                that conflict with one another
-            DagsterGraphQLClientError("PresetNotFoundError", message): if the provided preset name is not found
-            DagsterGraphQLClientError("RunConflict", message): a `DagsterRunConflict` occured during execution.
-                This indicates that a conflicting pipeline run already exists in run storage.
-            DagsterGraphQLClientError("PipelineConfigurationInvalid", invalid_step_key): the run_config is not in the expected format
-                for the pipeline
-            DagsterGraphQLClientError("PipelineNotFoundError", message): the requested pipeline does not exist
-            DagsterGraphQLClientError("PythonError", message): an internal framework error occurred
-
-        Returns:
-            str: run id of the submitted pipeline run
-        """
-        return self._core_submit_execution(
-            pipeline_name,
-            repository_location_name,
-            repository_name,
-            run_config,
-            mode,
-            preset,
-            tags,
-            solid_selection,
-            is_using_job_op_graph_apis=False,
-        )
-
     @public
     def submit_job_execution(
         self,
@@ -283,7 +221,7 @@ class DagsterGraphQLClient:
         repository_name: Optional[str] = None,
         run_config: Optional[Dict[str, Any]] = None,
         tags: Optional[Dict[str, Any]] = None,
-        op_selection: Optional[List[str]] = None,
+        op_selection: Optional[Sequence[str]] = None,
     ) -> str:
         """Submits a job with attached configuration for execution.
 
@@ -324,7 +262,7 @@ class DagsterGraphQLClient:
             mode="default",
             preset=None,
             tags=tags,
-            solid_selection=op_selection,
+            op_selection=op_selection,
             is_using_job_op_graph_apis=True,
         )
 
