@@ -10,7 +10,7 @@ from dagster._core.events import EngineEventData
 from dagster._core.instance import DagsterInstance
 from dagster._core.storage.captured_log_manager import CapturedLogManager
 from dagster._core.storage.compute_log_manager import ComputeIOType, ComputeLogFileData
-from dagster._core.storage.pipeline_run import DagsterRunStatus
+from dagster._core.storage.dagster_run import CANCELABLE_RUN_STATUSES
 from dagster._core.workspace.permissions import Permissions
 from dagster._utils.error import serializable_error_info_from_exc_info
 from starlette.concurrency import (
@@ -23,7 +23,6 @@ if TYPE_CHECKING:
 from ..utils import (
     assert_permission,
     assert_permission_for_location,
-    capture_error,
 )
 from .backfill import (
     cancel_partition_backfill as cancel_partition_backfill,
@@ -98,9 +97,7 @@ def terminate_pipeline_execution(
     run = record.dagster_run
     graphene_run = GrapheneRun(record)
 
-    location_name = (
-        run.external_pipeline_origin.location_name if run.external_pipeline_origin else None
-    )
+    location_name = run.external_job_origin.location_name if run.external_job_origin else None
 
     if location_name:
         assert_permission_for_location(
@@ -109,7 +106,7 @@ def terminate_pipeline_execution(
     else:
         assert_permission(graphene_info, Permissions.TERMINATE_PIPELINE_EXECUTION)
 
-    can_cancel_run = run.status == DagsterRunStatus.STARTED or run.status == DagsterRunStatus.QUEUED
+    can_cancel_run = run.status in CANCELABLE_RUN_STATUSES
 
     valid_status = not run.is_finished and (force_mark_as_canceled or can_cancel_run)
 
@@ -131,7 +128,7 @@ def terminate_pipeline_execution(
                     "Exception while attempting to force-terminate run. Run will still be marked as"
                     " canceled."
                 ),
-                pipeline_name=run.pipeline_name,
+                job_name=run.job_name,
                 run_id=run.run_id,
                 engine_event_data=EngineEventData(
                     error=serializable_error_info_from_exc_info(sys.exc_info()),
@@ -147,7 +144,6 @@ def terminate_pipeline_execution(
     )
 
 
-@capture_error
 def delete_pipeline_run(
     graphene_info: "ResolveInfo", run_id: str
 ) -> Union["GrapheneDeletePipelineRunSuccess", "GrapheneRunNotFoundError"]:
@@ -160,9 +156,7 @@ def delete_pipeline_run(
     if not run:
         return GrapheneRunNotFoundError(run_id)
 
-    location_name = (
-        run.external_pipeline_origin.location_name if run.external_pipeline_origin else None
-    )
+    location_name = run.external_job_origin.location_name if run.external_job_origin else None
     if location_name:
         assert_permission_for_location(
             graphene_info, Permissions.DELETE_PIPELINE_RUN, location_name
@@ -231,7 +225,7 @@ async def gen_events_for_run(
             yield GraphenePipelineRunLogsSubscriptionSuccess(
                 run=GrapheneRun(record),
                 messages=[
-                    from_event_record(record.event_log_entry, run.pipeline_name)
+                    from_event_record(record.event_log_entry, run.job_name)
                     for record in connection.records
                 ],
                 hasMorePastEvents=connection.has_more,
@@ -253,7 +247,7 @@ async def gen_events_for_run(
             event, cursor = await queue.get()
             yield GraphenePipelineRunLogsSubscriptionSuccess(
                 run=GrapheneRun(record),
-                messages=[from_event_record(event, run.pipeline_name)],
+                messages=[from_event_record(event, run.job_name)],
                 hasMorePastEvents=False,
                 cursor=cursor,
             )
@@ -325,7 +319,6 @@ async def gen_captured_log_data(
         subscription.dispose()
 
 
-@capture_error
 def wipe_assets(
     graphene_info: "ResolveInfo", asset_keys: Sequence[AssetKey]
 ) -> "GrapheneAssetWipeSuccess":
