@@ -1,18 +1,17 @@
 from typing import TYPE_CHECKING, cast
 
 import dagster._check as check
-from dagster._core.definitions.selector import PipelineSelector
+from dagster._core.definitions.selector import JobSubsetSelector
 from dagster._core.execution.plan.resume_retry import ReexecutionStrategy
 from dagster._core.instance import DagsterInstance
-from dagster._core.storage.pipeline_run import DagsterRun, RunsFilter
+from dagster._core.storage.dagster_run import DagsterRun, RunsFilter
 from dagster._core.workspace.permissions import Permissions
 
-from ..external import get_external_pipeline_or_raise
+from ..external import get_external_job_or_raise
 from ..utils import (
     ExecutionMetadata,
     ExecutionParams,
     assert_permission_for_location,
-    capture_error,
 )
 from .run_lifecycle import create_valid_pipeline_run
 
@@ -21,14 +20,12 @@ if TYPE_CHECKING:
     from dagster_graphql.schema.util import ResolveInfo
 
 
-@capture_error
 def launch_pipeline_reexecution(
     graphene_info: "ResolveInfo", execution_params: ExecutionParams
 ) -> "GrapheneLaunchRunSuccess":
     return _launch_pipeline_execution(graphene_info, execution_params, is_reexecuted=True)
 
 
-@capture_error
 def launch_pipeline_execution(
     graphene_info: "ResolveInfo", execution_params: ExecutionParams
 ) -> "GrapheneLaunchRunSuccess":
@@ -48,11 +45,11 @@ def do_launch(
         )
         check.str_param(execution_metadata.root_run_id, "root_run_id")
         check.str_param(execution_metadata.parent_run_id, "parent_run_id")
-    external_pipeline = get_external_pipeline_or_raise(graphene_info, execution_params.selector)
-    pipeline_run = create_valid_pipeline_run(graphene_info, external_pipeline, execution_params)
+    external_job = get_external_job_or_raise(graphene_info, execution_params.selector)
+    dagster_run = create_valid_pipeline_run(graphene_info, external_job, execution_params)
 
     return graphene_info.context.instance.submit_run(
-        pipeline_run.run_id,
+        dagster_run.run_id,
         workspace=graphene_info.context,
     )
 
@@ -72,7 +69,6 @@ def _launch_pipeline_execution(
     return GrapheneLaunchRunSuccess(run=GrapheneRun(records[0]))
 
 
-@capture_error
 def launch_reexecution_from_parent_run(
     graphene_info: "ResolveInfo", parent_run_id: str, strategy: str
 ) -> "GrapheneLaunchRunSuccess":
@@ -86,12 +82,12 @@ def launch_reexecution_from_parent_run(
     parent_run = check.not_none(
         instance.get_run_by_id(parent_run_id), f"Could not find parent run with id: {parent_run_id}"
     )
-    origin = check.not_none(parent_run.external_pipeline_origin)
-    selector = PipelineSelector(
+    origin = check.not_none(parent_run.external_job_origin)
+    selector = JobSubsetSelector(
         location_name=origin.external_repository_origin.code_location_origin.location_name,
         repository_name=origin.external_repository_origin.repository_name,
-        pipeline_name=parent_run.pipeline_name,
-        solid_selection=None,
+        job_name=parent_run.job_name,
+        op_selection=None,
     )
 
     assert_permission_for_location(
@@ -101,12 +97,12 @@ def launch_reexecution_from_parent_run(
     )
 
     repo_location = graphene_info.context.get_code_location(selector.location_name)
-    external_pipeline = get_external_pipeline_or_raise(graphene_info, selector)
+    external_pipeline = get_external_job_or_raise(graphene_info, selector)
 
     run = instance.create_reexecuted_run(
         parent_run=cast(DagsterRun, parent_run),
         code_location=repo_location,
-        external_pipeline=external_pipeline,
+        external_job=external_pipeline,
         strategy=ReexecutionStrategy(strategy),
         use_parent_run_tags=True,  # inherit whatever tags were set on the parent run at launch time
     )
