@@ -3,15 +3,15 @@ from typing import TYPE_CHECKING, Optional, Sequence, Tuple, cast
 import dagster._check as check
 from dagster._core.errors import DagsterRunNotFoundError
 from dagster._core.execution.plan.state import KnownExecutionState
-from dagster._core.host_representation.external import ExternalPipeline
+from dagster._core.host_representation.external import ExternalJob
 from dagster._core.instance import DagsterInstance
-from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus
+from dagster._core.storage.dagster_run import DagsterRun, DagsterRunStatus
 from dagster._core.storage.tags import RESUME_RETRY_TAG
 from dagster._core.utils import make_new_run_id
 from dagster._utils.merger import merge_dicts
 
 from ..external import ensure_valid_config, get_external_execution_plan_or_raise
-from ..utils import ExecutionParams, UserFacingGraphQLError
+from ..utils import ExecutionParams
 
 if TYPE_CHECKING:
     from dagster_graphql.schema.util import ResolveInfo
@@ -58,23 +58,10 @@ def is_resume_retry(execution_params: ExecutionParams) -> bool:
 
 def create_valid_pipeline_run(
     graphene_info: "ResolveInfo",
-    external_pipeline: ExternalPipeline,
+    external_pipeline: ExternalJob,
     execution_params: ExecutionParams,
 ) -> DagsterRun:
-    from ...schema.errors import GrapheneNoModeProvidedError
-
-    mode: Optional[str]
-    if execution_params.mode is None and len(external_pipeline.available_modes) > 1:
-        raise UserFacingGraphQLError(
-            GrapheneNoModeProvidedError(external_pipeline.name, external_pipeline.available_modes)
-        )
-    elif execution_params.mode is None and len(external_pipeline.available_modes) == 1:
-        mode = external_pipeline.available_modes[0]
-
-    else:
-        mode = execution_params.mode
-
-    ensure_valid_config(external_pipeline, mode, execution_params.run_config)
+    ensure_valid_config(external_pipeline, execution_params.run_config)
 
     step_keys_to_execute, known_state = compute_step_keys_to_execute(
         graphene_info, execution_params
@@ -83,37 +70,35 @@ def create_valid_pipeline_run(
     external_execution_plan = get_external_execution_plan_or_raise(
         graphene_info=graphene_info,
         external_pipeline=external_pipeline,
-        mode=mode,
         run_config=execution_params.run_config,
         step_keys_to_execute=step_keys_to_execute,
         known_state=known_state,
     )
     tags = merge_dicts(external_pipeline.tags, execution_params.execution_metadata.tags)
 
-    pipeline_run = graphene_info.context.instance.create_run(
-        pipeline_snapshot=external_pipeline.pipeline_snapshot,
+    dagster_run = graphene_info.context.instance.create_run(
+        job_snapshot=external_pipeline.job_snapshot,
         execution_plan_snapshot=external_execution_plan.execution_plan_snapshot,
-        parent_pipeline_snapshot=external_pipeline.parent_pipeline_snapshot,
-        pipeline_name=execution_params.selector.pipeline_name,
+        parent_job_snapshot=external_pipeline.parent_job_snapshot,
+        job_name=execution_params.selector.job_name,
         run_id=execution_params.execution_metadata.run_id
         if execution_params.execution_metadata.run_id
         else make_new_run_id(),
         asset_selection=frozenset(execution_params.selector.asset_selection)
         if execution_params.selector.asset_selection
         else None,
-        solid_selection=execution_params.selector.solid_selection,
-        solids_to_execute=frozenset(execution_params.selector.solid_selection)
-        if execution_params.selector.solid_selection
+        op_selection=execution_params.selector.op_selection,
+        resolved_op_selection=frozenset(execution_params.selector.op_selection)
+        if execution_params.selector.op_selection
         else None,
         run_config=execution_params.run_config,
-        mode=mode,
         step_keys_to_execute=step_keys_to_execute,
         tags=tags,
         root_run_id=execution_params.execution_metadata.root_run_id,
         parent_run_id=execution_params.execution_metadata.parent_run_id,
         status=DagsterRunStatus.NOT_STARTED,
-        external_pipeline_origin=external_pipeline.get_external_origin(),
-        pipeline_code_origin=external_pipeline.get_python_origin(),
+        external_job_origin=external_pipeline.get_external_origin(),
+        job_code_origin=external_pipeline.get_python_origin(),
     )
 
-    return pipeline_run
+    return dagster_run
