@@ -5,14 +5,14 @@ from typing import TYPE_CHECKING, Mapping, Optional, Sequence, Union
 
 import dagster._check as check
 from dagster._config import validate_config_from_snap
-from dagster._core.definitions.selector import PipelineSelector, RepositorySelector
+from dagster._core.definitions.selector import JobSubsetSelector, RepositorySelector
 from dagster._core.execution.plan.state import KnownExecutionState
-from dagster._core.host_representation import ExternalPipeline
+from dagster._core.host_representation import ExternalJob
 from dagster._core.host_representation.external import ExternalExecutionPlan
 from dagster._core.workspace.context import BaseWorkspaceRequestContext, WorkspaceRequestContext
 from dagster._utils.error import serializable_error_info_from_exc_info
 
-from .utils import UserFacingGraphQLError, capture_error
+from .utils import UserFacingGraphQLError
 
 if TYPE_CHECKING:
     from dagster_graphql.schema.errors import GrapheneRepositoryNotFoundError
@@ -25,24 +25,24 @@ if TYPE_CHECKING:
     from dagster_graphql.schema.util import ResolveInfo
 
 
-def get_full_external_pipeline_or_raise(
+def get_full_external_job_or_raise(
     graphene_info: "ResolveInfo",
-    selector: PipelineSelector,
-) -> ExternalPipeline:
-    check.inst_param(selector, "selector", PipelineSelector)
-    return _get_external_pipeline_or_raise(graphene_info, selector, ignore_subset=True)
+    selector: JobSubsetSelector,
+) -> ExternalJob:
+    check.inst_param(selector, "selector", JobSubsetSelector)
+    return _get_external_job_or_raise(graphene_info, selector, ignore_subset=True)
 
 
-def get_external_pipeline_or_raise(
-    graphene_info: "ResolveInfo", selector: PipelineSelector
-) -> ExternalPipeline:
-    check.inst_param(selector, "selector", PipelineSelector)
-    return _get_external_pipeline_or_raise(graphene_info, selector)
+def get_external_job_or_raise(
+    graphene_info: "ResolveInfo", selector: JobSubsetSelector
+) -> ExternalJob:
+    check.inst_param(selector, "selector", JobSubsetSelector)
+    return _get_external_job_or_raise(graphene_info, selector)
 
 
-def _get_external_pipeline_or_raise(
-    graphene_info: "ResolveInfo", selector: PipelineSelector, ignore_subset: bool = False
-) -> ExternalPipeline:
+def _get_external_job_or_raise(
+    graphene_info: "ResolveInfo", selector: JobSubsetSelector, ignore_subset: bool = False
+) -> ExternalJob:
     from ..schema.errors import GrapheneInvalidSubsetError, GraphenePipelineNotFoundError
     from ..schema.pipelines.pipeline import GraphenePipeline
 
@@ -50,11 +50,11 @@ def _get_external_pipeline_or_raise(
     if not ctx.has_external_job(selector):
         raise UserFacingGraphQLError(GraphenePipelineNotFoundError(selector=selector))
     elif ignore_subset:
-        external_pipeline = ctx.get_full_external_job(selector)
+        external_job = ctx.get_full_external_job(selector)
     else:
         code_location = ctx.get_code_location(selector.location_name)
         try:
-            external_pipeline = code_location.get_external_pipeline(selector)
+            external_job = code_location.get_external_job(selector)
         except Exception:
             error_info = serializable_error_info_from_exc_info(sys.exc_info())
             raise UserFacingGraphQLError(
@@ -67,28 +67,25 @@ def _get_external_pipeline_or_raise(
                 )
             )
 
-    return external_pipeline
+    return external_job
 
 
-def ensure_valid_config(
-    external_pipeline: ExternalPipeline, mode: Optional[str], run_config: object
-) -> object:
+def ensure_valid_config(external_job: ExternalJob, run_config: object) -> object:
     from ..schema.pipelines.config import GrapheneRunConfigValidationInvalid
 
-    check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
-    check.opt_str_param(mode, "mode")
+    check.inst_param(external_job, "external_job", ExternalJob)
     # do not type check run_config so that validate_config_from_snap throws
 
     validated_config = validate_config_from_snap(
-        config_schema_snapshot=external_pipeline.config_schema_snapshot,
-        config_type_key=check.not_none(external_pipeline.root_config_key_for_mode(mode)),
+        config_schema_snapshot=external_job.config_schema_snapshot,
+        config_type_key=check.not_none(external_job.root_config_key),
         config_value=run_config,
     )
 
     if not validated_config.success:
         raise UserFacingGraphQLError(
             GrapheneRunConfigValidationInvalid.for_validation_errors(
-                external_pipeline, validated_config.errors
+                external_job, validated_config.errors
             )
         )
 
@@ -97,22 +94,19 @@ def ensure_valid_config(
 
 def get_external_execution_plan_or_raise(
     graphene_info: "ResolveInfo",
-    external_pipeline: ExternalPipeline,
-    mode: Optional[str],
+    external_pipeline: ExternalJob,
     run_config: Mapping[str, object],
     step_keys_to_execute: Optional[Sequence[str]],
     known_state: Optional[KnownExecutionState],
 ) -> ExternalExecutionPlan:
     return graphene_info.context.get_external_execution_plan(
-        external_pipeline=external_pipeline,
+        external_job=external_pipeline,
         run_config=run_config,
-        mode=check.not_none(mode),
         step_keys_to_execute=step_keys_to_execute,
         known_state=known_state,
     )
 
 
-@capture_error
 def fetch_repositories(graphene_info: "ResolveInfo") -> GrapheneRepositoryConnection:
     from ..schema.external import GrapheneRepository, GrapheneRepositoryConnection
 
@@ -129,7 +123,6 @@ def fetch_repositories(graphene_info: "ResolveInfo") -> GrapheneRepositoryConnec
     )
 
 
-@capture_error
 def fetch_repository(
     graphene_info: "ResolveInfo", repository_selector: RepositorySelector
 ) -> Union[GrapheneRepository, GrapheneRepositoryNotFoundError]:
@@ -152,7 +145,6 @@ def fetch_repository(
     )
 
 
-@capture_error
 def fetch_workspace(workspace_request_context: WorkspaceRequestContext) -> GrapheneWorkspace:
     from ..schema.external import GrapheneWorkspace, GrapheneWorkspaceLocationEntry
 
@@ -168,7 +160,6 @@ def fetch_workspace(workspace_request_context: WorkspaceRequestContext) -> Graph
     return GrapheneWorkspace(locationEntries=nodes)
 
 
-@capture_error
 def fetch_location_statuses(
     workspace_request_context: WorkspaceRequestContext,
 ) -> GrapheneWorkspaceLocationStatusEntries:
