@@ -60,17 +60,15 @@ from dagster_graphql.implementation.loader import (
     StaleStatusLoader,
 )
 
-from .utils import capture_error
-
 if TYPE_CHECKING:
     from ..schema.asset_graph import GrapheneAssetNode, GrapheneAssetNodeDefinitionCollision
     from ..schema.errors import GrapheneAssetNotFoundError
     from ..schema.freshness_policy import GrapheneAssetFreshnessInfo
     from ..schema.pipelines.pipeline import (
         GrapheneAsset,
-        GrapheneDefaultPartitions,
-        GrapheneMultiPartitions,
-        GrapheneTimePartitions,
+        GrapheneDefaultPartitionStatuses,
+        GrapheneMultiPartitionStatuses,
+        GrapheneTimePartitionStatuses,
     )
     from ..schema.roots.assets import GrapheneAssetConnection
     from ..schema.util import ResolveInfo
@@ -90,7 +88,6 @@ def _normalize_asset_cursor_str(cursor_string: Optional[str]) -> Optional[str]:
         return cursor_string
 
 
-@capture_error
 def get_assets(
     graphene_info: "ResolveInfo",
     prefix: Optional[Sequence[str]] = None,
@@ -296,12 +293,6 @@ def get_asset_observations(
     return [event_record.event_log_entry for event_record in event_records]
 
 
-def get_asset_run_ids(graphene_info: "ResolveInfo", asset_key: AssetKey) -> Sequence[str]:
-    check.inst_param(asset_key, "asset_key", AssetKey)
-    instance = graphene_info.context.instance
-    return instance.run_ids_for_asset_key(asset_key)
-
-
 def get_assets_for_run_id(graphene_info: "ResolveInfo", run_id: str) -> Sequence["GrapheneAsset"]:
     from ..schema.pipelines.pipeline import GrapheneAsset
 
@@ -408,11 +399,15 @@ def build_partition_statuses(
     materialized_partitions_subset: Optional[PartitionsSubset],
     failed_partitions_subset: Optional[PartitionsSubset],
     in_progress_partitions_subset: Optional[PartitionsSubset],
-) -> Union["GrapheneTimePartitions", "GrapheneDefaultPartitions", "GrapheneMultiPartitions"]:
+) -> Union[
+    "GrapheneTimePartitionStatuses",
+    "GrapheneDefaultPartitionStatuses",
+    "GrapheneMultiPartitionStatuses",
+]:
     from ..schema.pipelines.pipeline import (
-        GrapheneDefaultPartitions,
-        GrapheneTimePartitionRange,
-        GrapheneTimePartitions,
+        GrapheneDefaultPartitionStatuses,
+        GrapheneTimePartitionRangeStatus,
+        GrapheneTimePartitionStatuses,
     )
 
     if (
@@ -420,7 +415,7 @@ def build_partition_statuses(
         and failed_partitions_subset is None
         and in_progress_partitions_subset is None
     ):
-        return GrapheneDefaultPartitions(
+        return GrapheneDefaultPartitionStatuses(
             materializedPartitions=[],
             failedPartitions=[],
             unmaterializedPartitions=[],
@@ -458,7 +453,7 @@ def build_partition_statuses(
                 TimeWindowPartitionsDefinition, materialized_partitions_subset.partitions_def
             ).get_partition_key_range_for_time_window(r.time_window)
             graphene_ranges.append(
-                GrapheneTimePartitionRange(
+                GrapheneTimePartitionRangeStatus(
                     startTime=r.time_window.start.timestamp(),
                     endTime=r.time_window.end.timestamp(),
                     startKey=partition_key_range.start,
@@ -466,7 +461,7 @@ def build_partition_statuses(
                     status=r.status,
                 )
             )
-        return GrapheneTimePartitions(ranges=graphene_ranges)
+        return GrapheneTimePartitionStatuses(ranges=graphene_ranges)
     elif isinstance(materialized_partitions_subset, MultiPartitionsSubset):
         return get_2d_run_length_encoded_partitions(
             dynamic_partitions_store,
@@ -479,7 +474,7 @@ def build_partition_statuses(
         failed_keys = failed_partitions_subset.get_partition_keys()
         in_progress_keys = in_progress_partitions_subset.get_partition_keys()
 
-        return GrapheneDefaultPartitions(
+        return GrapheneDefaultPartitionStatuses(
             materializedPartitions=set(materialized_keys)
             - set(failed_keys)
             - set(in_progress_keys),
@@ -498,10 +493,10 @@ def get_2d_run_length_encoded_partitions(
     materialized_partitions_subset: PartitionsSubset,
     failed_partitions_subset: PartitionsSubset,
     in_progress_partitions_subset: PartitionsSubset,
-) -> "GrapheneMultiPartitions":
+) -> "GrapheneMultiPartitionStatuses":
     from ..schema.pipelines.pipeline import (
-        GrapheneMultiPartitionRange,
-        GrapheneMultiPartitions,
+        GrapheneMultiPartitionRangeStatuses,
+        GrapheneMultiPartitionStatuses,
     )
 
     if (
@@ -573,7 +568,7 @@ def get_2d_run_length_encoded_partitions(
         )
         == 0
     ):
-        return GrapheneMultiPartitions(ranges=[], primaryDimensionName=primary_dim.name)
+        return GrapheneMultiPartitionStatuses(ranges=[], primaryDimensionName=primary_dim.name)
 
     while unevaluated_idx <= len(dim1_keys):
         if (
@@ -608,7 +603,7 @@ def get_2d_run_length_encoded_partitions(
                     end_time = None
 
                 materialized_2d_ranges.append(
-                    GrapheneMultiPartitionRange(
+                    GrapheneMultiPartitionRangeStatuses(
                         primaryDimStartKey=start_key,
                         primaryDimEndKey=end_key,
                         primaryDimStartTime=start_time,
@@ -624,7 +619,7 @@ def get_2d_run_length_encoded_partitions(
             range_start_idx = unevaluated_idx
         unevaluated_idx += 1
 
-    return GrapheneMultiPartitions(
+    return GrapheneMultiPartitionStatuses(
         ranges=materialized_2d_ranges, primaryDimensionName=primary_dim.name
     )
 
