@@ -1,10 +1,7 @@
 from typing import TYPE_CHECKING, Optional
 
-import dagster._check as check
 from dagster._core.execution.backfill import BulkActionStatus
 
-from .utils import capture_error
-
 if TYPE_CHECKING:
     from dagster_graphql.schema.util import ResolveInfo
 
@@ -14,16 +11,16 @@ if TYPE_CHECKING:
     )
 
 
-@capture_error
 def get_backfill(graphene_info: "ResolveInfo", backfill_id: str) -> "GraphenePartitionBackfill":
-    from ..schema.backfill import GraphenePartitionBackfill
+    from ..schema.backfill import GrapheneBackfillNotFoundError, GraphenePartitionBackfill
+
+    backfill_job = graphene_info.context.instance.get_backfill(backfill_id)
+    if backfill_job is None:
+        return GrapheneBackfillNotFoundError(backfill_id)
 
-    # get_backfill can return None but this resolver assumes that the backfill exists
-    backfill_job = check.not_none(graphene_info.context.instance.get_backfill(backfill_id))
     return GraphenePartitionBackfill(backfill_job)
 
 
-@capture_error
 def get_backfills(
     graphene_info: "ResolveInfo",
     status: Optional[BulkActionStatus] = None,
