@@ -1,13 +1,13 @@
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Optional, Sequence, Set
 
 import dagster._check as check
 from dagster._core.definitions.run_request import InstigatorType
 from dagster._core.definitions.selector import (
-    PipelineSelector,
+    JobSubsetSelector,
     RepositorySelector,
     ScheduleSelector,
 )
-from dagster._core.scheduler.instigation import InstigatorState
+from dagster._core.scheduler.instigation import InstigatorState, InstigatorStatus
 from dagster._core.workspace.permissions import Permissions
 from dagster._seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
 
@@ -18,7 +18,6 @@ from .utils import (
     UserFacingGraphQLError,
     assert_permission,
     assert_permission_for_location,
-    capture_error,
 )
 
 if TYPE_CHECKING:
@@ -31,7 +30,6 @@ if TYPE_CHECKING:
     )
 
 
-@capture_error
 def start_schedule(
     graphene_info: ResolveInfo, schedule_selector: ScheduleSelector
 ) -> "GrapheneScheduleStateResult":
@@ -48,7 +46,6 @@ def start_schedule(
     return GrapheneScheduleStateResult(GrapheneInstigationState(schedule_state))
 
 
-@capture_error
 def stop_schedule(
     graphene_info: ResolveInfo, schedule_origin_id: str, schedule_selector_id: str
 ) -> "GrapheneScheduleStateResult":
@@ -84,7 +81,6 @@ def stop_schedule(
     return GrapheneScheduleStateResult(GrapheneInstigationState(schedule_state))
 
 
-@capture_error
 def get_scheduler_or_error(graphene_info: ResolveInfo) -> "GrapheneScheduler":
     from ..schema.errors import GrapheneSchedulerNotDefinedError
     from ..schema.schedules import GrapheneScheduler
@@ -97,9 +93,10 @@ def get_scheduler_or_error(graphene_info: ResolveInfo) -> "GrapheneScheduler":
     return GrapheneScheduler(scheduler_class=instance.scheduler.__class__.__name__)
 
 
-@capture_error
 def get_schedules_or_error(
-    graphene_info: ResolveInfo, repository_selector: RepositorySelector
+    graphene_info: ResolveInfo,
+    repository_selector: RepositorySelector,
+    instigator_statuses: Optional[Set[InstigatorStatus]] = None,
 ) -> "GrapheneSchedules":
     from ..schema.schedules import GrapheneSchedule, GrapheneSchedules
 
@@ -109,31 +106,40 @@ def get_schedules_or_error(
     repository = location.get_repository(repository_selector.repository_name)
     batch_loader = RepositoryScopedBatchLoader(graphene_info.context.instance, repository)
     external_schedules = repository.get_external_schedules()
-    schedule_states_by_name = {
-        state.name: state
-        for state in graphene_info.context.instance.all_instigator_state(
-            repository_origin_id=repository.get_external_origin_id(),
-            repository_selector_id=repository_selector.selector_id,
-            instigator_type=InstigatorType.SCHEDULE,
-        )
-    }
+    schedule_states = graphene_info.context.instance.all_instigator_state(
+        repository_origin_id=repository.get_external_origin_id(),
+        repository_selector_id=repository_selector.selector_id,
+        instigator_type=InstigatorType.SCHEDULE,
+        instigator_statuses=instigator_statuses,
+    )
+
+    schedule_states_by_name = {state.name: state for state in schedule_states}
+    if instigator_statuses:
+        filtered = [
+            external_schedule
+            for external_schedule in external_schedules
+            if external_schedule.get_current_instigator_state(
+                schedule_states_by_name.get(external_schedule.name)
+            ).status
+            in instigator_statuses
+        ]
+    else:
+        filtered = external_schedules
 
     results = [
-        GrapheneSchedule(
-            external_schedule, schedule_states_by_name.get(external_schedule.name), batch_loader
-        )
-        for external_schedule in external_schedules
+        GrapheneSchedule(schedule, schedule_states_by_name.get(schedule.name), batch_loader)
+        for schedule in filtered
     ]
 
     return GrapheneSchedules(results=results)
 
 
 def get_schedules_for_pipeline(
-    graphene_info: ResolveInfo, pipeline_selector: PipelineSelector
+    graphene_info: ResolveInfo, pipeline_selector: JobSubsetSelector
 ) -> Sequence["GrapheneSchedule"]:
     from ..schema.schedules import GrapheneSchedule
 
-    check.inst_param(pipeline_selector, "pipeline_selector", PipelineSelector)
+    check.inst_param(pipeline_selector, "pipeline_selector", JobSubsetSelector)
 
     location = graphene_info.context.get_code_location(pipeline_selector.location_name)
     repository = location.get_repository(pipeline_selector.repository_name)
@@ -141,7 +147,7 @@ def get_schedules_for_pipeline(
 
     results = []
     for external_schedule in external_schedules:
-        if external_schedule.pipeline_name != pipeline_selector.pipeline_name:
+        if external_schedule.job_name != pipeline_selector.job_name:
             continue
 
         schedule_state = graphene_info.context.instance.get_instigator_state(
@@ -153,7 +159,6 @@ def get_schedules_for_pipeline(
     return results
 
 
-@capture_error
 def get_schedule_or_error(
     graphene_info: ResolveInfo, schedule_selector: ScheduleSelector
 ) -> "GrapheneSchedule":
