@@ -1,9 +1,13 @@
-from typing import TYPE_CHECKING, Optional, Sequence
+from typing import TYPE_CHECKING, Optional, Sequence, Set
 
 import dagster._check as check
 from dagster._core.definitions.run_request import InstigatorType
-from dagster._core.definitions.selector import PipelineSelector, RepositorySelector, SensorSelector
-from dagster._core.scheduler.instigation import InstigatorState, SensorInstigatorData
+from dagster._core.definitions.selector import JobSubsetSelector, RepositorySelector, SensorSelector
+from dagster._core.scheduler.instigation import (
+    InstigatorState,
+    InstigatorStatus,
+    SensorInstigatorData,
+)
 from dagster._core.workspace.permissions import Permissions
 from dagster._seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
 
@@ -14,21 +18,18 @@ from .utils import (
     UserFacingGraphQLError,
     assert_permission,
     assert_permission_for_location,
-    capture_error,
 )
 
 if TYPE_CHECKING:
     from dagster_graphql.schema.instigation import GrapheneDryRunInstigationTick
 
-    from ..schema.instigation import (
-        GrapheneInstigationStates,
-    )
     from ..schema.sensors import GrapheneSensor, GrapheneSensors, GrapheneStopSensorMutationResult
 
 
-@capture_error
 def get_sensors_or_error(
-    graphene_info: ResolveInfo, repository_selector: RepositorySelector
+    graphene_info: ResolveInfo,
+    repository_selector: RepositorySelector,
+    instigator_statuses: Optional[Set[InstigatorStatus]] = None,
 ) -> "GrapheneSensors":
     from ..schema.sensors import GrapheneSensor, GrapheneSensors
 
@@ -38,23 +39,32 @@ def get_sensors_or_error(
     repository = location.get_repository(repository_selector.repository_name)
     batch_loader = RepositoryScopedBatchLoader(graphene_info.context.instance, repository)
     sensors = repository.get_external_sensors()
-    sensor_states_by_name = {
-        state.name: state
-        for state in graphene_info.context.instance.all_instigator_state(
-            repository_origin_id=repository.get_external_origin_id(),
-            repository_selector_id=repository_selector.selector_id,
-            instigator_type=InstigatorType.SENSOR,
-        )
-    }
+    sensor_states = graphene_info.context.instance.all_instigator_state(
+        repository_origin_id=repository.get_external_origin_id(),
+        repository_selector_id=repository_selector.selector_id,
+        instigator_type=InstigatorType.SENSOR,
+        instigator_statuses=instigator_statuses,
+    )
+
+    sensor_states_by_name = {state.name: state for state in sensor_states}
+    if instigator_statuses:
+        filtered = [
+            sensor
+            for sensor in sensors
+            if sensor.get_current_instigator_state(sensor_states_by_name.get(sensor.name)).status
+            in instigator_statuses
+        ]
+    else:
+        filtered = sensors
+
     return GrapheneSensors(
         results=[
             GrapheneSensor(sensor, sensor_states_by_name.get(sensor.name), batch_loader)
-            for sensor in sensors
+            for sensor in filtered
         ]
     )
 
 
-@capture_error
 def get_sensor_or_error(graphene_info: ResolveInfo, selector: SensorSelector) -> "GrapheneSensor":
     from ..schema.errors import GrapheneSensorNotFoundError
     from ..schema.sensors import GrapheneSensor
@@ -74,7 +84,6 @@ def get_sensor_or_error(graphene_info: ResolveInfo, selector: SensorSelector) ->
     return GrapheneSensor(external_sensor, sensor_state)
 
 
-@capture_error
 def start_sensor(graphene_info: ResolveInfo, sensor_selector: SensorSelector) -> "GrapheneSensor":
     from ..schema.errors import GrapheneSensorNotFoundError
     from ..schema.sensors import GrapheneSensor
@@ -94,7 +103,6 @@ def start_sensor(graphene_info: ResolveInfo, sensor_selector: SensorSelector) ->
     return GrapheneSensor(external_sensor, sensor_state)
 
 
-@capture_error
 def stop_sensor(
     graphene_info: ResolveInfo, instigator_origin_id: str, instigator_selector_id: str
 ) -> "GrapheneStopSensorMutationResult":
@@ -131,46 +139,12 @@ def stop_sensor(
     return GrapheneStopSensorMutationResult(state)
 
 
-@capture_error
-def get_unloadable_sensor_states_or_error(
-    graphene_info: ResolveInfo,
-) -> "GrapheneInstigationStates":
-    from ..schema.instigation import GrapheneInstigationState, GrapheneInstigationStates
-
-    sensor_states = graphene_info.context.instance.all_instigator_state(
-        instigator_type=InstigatorType.SENSOR
-    )
-    external_sensors = [
-        sensor
-        for repository_location in graphene_info.context.code_locations
-        for repository in repository_location.get_repositories().values()
-        for sensor in repository.get_external_sensors()
-    ]
-
-    sensor_origin_ids = {
-        external_sensor.get_external_origin_id() for external_sensor in external_sensors
-    }
-
-    unloadable_states = [
-        sensor_state
-        for sensor_state in sensor_states
-        if sensor_state.instigator_origin_id not in sensor_origin_ids
-    ]
-
-    return GrapheneInstigationStates(
-        results=[
-            GrapheneInstigationState(instigator_state=sensor_state)
-            for sensor_state in unloadable_states
-        ]
-    )
-
-
 def get_sensors_for_pipeline(
-    graphene_info: ResolveInfo, pipeline_selector: PipelineSelector
+    graphene_info: ResolveInfo, pipeline_selector: JobSubsetSelector
 ) -> Sequence["GrapheneSensor"]:
     from ..schema.sensors import GrapheneSensor
 
-    check.inst_param(pipeline_selector, "pipeline_selector", PipelineSelector)
+    check.inst_param(pipeline_selector, "pipeline_selector", JobSubsetSelector)
 
     location = graphene_info.context.get_code_location(pipeline_selector.location_name)
     repository = location.get_repository(pipeline_selector.repository_name)
@@ -178,8 +152,8 @@ def get_sensors_for_pipeline(
 
     results = []
     for external_sensor in external_sensors:
-        if pipeline_selector.pipeline_name not in [
-            target.pipeline_name for target in external_sensor.get_external_targets()
+        if pipeline_selector.job_name not in [
+            target.job_name for target in external_sensor.get_external_targets()
         ]:
             continue
 
@@ -234,7 +208,6 @@ def get_sensor_next_tick(
     return GrapheneDryRunInstigationTick(external_sensor.sensor_selector, next_timestamp)
 
 
-@capture_error
 def set_sensor_cursor(
     graphene_info: ResolveInfo, selector: SensorSelector, cursor: Optional[str]
 ) -> "GrapheneSensor":
