@@ -2,12 +2,14 @@ from typing import TYPE_CHECKING, Mapping, Optional
 
 import dagster._check as check
 from dagster._config import validate_config_from_snap
-from dagster._core.host_representation import RepresentedPipeline
+from dagster._core.host_representation import RepresentedJob
+from dagster._core.host_representation.external_data import DEFAULT_MODE_NAME
 
+from dagster_graphql.schema.errors import GrapheneModeNotFoundError
 from dagster_graphql.schema.util import ResolveInfo
 
-from .external import get_external_pipeline_or_raise
-from .utils import PipelineSelector, UserFacingGraphQLError, capture_error
+from .external import get_external_job_or_raise
+from .utils import JobSubsetSelector, UserFacingGraphQLError
 
 if TYPE_CHECKING:
     from ..schema.pipelines.config import (
@@ -16,34 +18,30 @@ if TYPE_CHECKING:
     from ..schema.run_config import GrapheneRunConfigSchema
 
 
-@capture_error
 def resolve_run_config_schema_or_error(
-    graphene_info: ResolveInfo, selector: PipelineSelector, mode: Optional[str]
+    graphene_info: ResolveInfo, selector: JobSubsetSelector, mode: Optional[str] = None
 ) -> "GrapheneRunConfigSchema":
-    from ..schema.errors import GrapheneModeNotFoundError
     from ..schema.run_config import GrapheneRunConfigSchema
 
-    check.inst_param(selector, "selector", PipelineSelector)
-    check.opt_str_param(mode, "mode")
+    check.inst_param(selector, "selector", JobSubsetSelector)
 
-    external_pipeline = get_external_pipeline_or_raise(graphene_info, selector)
+    # Mode has been eliminated from the definitions layer, so we perform a "shallow" check for
+    # invalid mode. This is temporary and will be removed when the GQL API transitions to
+    # job/op/graph.
+    if mode and mode != DEFAULT_MODE_NAME:
+        return GrapheneModeNotFoundError(selector=selector, mode=mode)
 
-    if mode is None:
-        mode = external_pipeline.get_default_mode_name()
-
-    if not external_pipeline.has_mode(mode):
-        raise UserFacingGraphQLError(GrapheneModeNotFoundError(mode=mode, selector=selector))
+    external_job = get_external_job_or_raise(graphene_info, selector)
 
     return GrapheneRunConfigSchema(
-        represented_pipeline=external_pipeline,
-        mode=mode,
+        represented_job=external_job,
+        mode=DEFAULT_MODE_NAME,
     )
 
 
-@capture_error
 def resolve_is_run_config_valid(
     graphene_info: ResolveInfo,
-    represented_pipeline: RepresentedPipeline,
+    represented_pipeline: RepresentedJob,
     mode: str,
     run_config: Mapping[str, object],
 ) -> "GraphenePipelineConfigValidationValid":
@@ -53,7 +51,7 @@ def resolve_is_run_config_valid(
         GrapheneRunConfigValidationInvalid,
     )
 
-    check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
+    check.inst_param(represented_pipeline, "represented_pipeline", RepresentedJob)
     check.str_param(mode, "mode")
     check.dict_param(run_config, "run_config", key_type=str)
 
