@@ -298,7 +298,6 @@ class GrapheneRepository(graphene.ObjectType):
             for pipeline in sorted(
                 self._repository.get_all_external_jobs(), key=lambda pipeline: pipeline.name
             )
-            if pipeline.is_job
         ]
 
     def resolve_usedSolid(self, _graphene_info: ResolveInfo, name):
@@ -370,11 +369,15 @@ class GrapheneRepositoryConnection(graphene.ObjectType):
 
 
 class GrapheneWorkspace(graphene.ObjectType):
+    id = graphene.NonNull(graphene.String)
     locationEntries = non_null_list(GrapheneWorkspaceLocationEntry)
 
     class Meta:
         name = "Workspace"
 
+    def resolve_id(self, _graphene_info: ResolveInfo):
+        return "Workspace"
+
 
 class GrapheneLocationStateChangeEvent(graphene.ObjectType):
     event_type = graphene.NonNull(GrapheneLocationStateChangeEventType)
