@@ -14,6 +14,7 @@ class GrapheneAssetFreshnessInfo(graphene.ObjectType):
 class GrapheneFreshnessPolicy(graphene.ObjectType):
     maximumLagMinutes = graphene.NonNull(graphene.Float)
     cronSchedule = graphene.Field(graphene.String)
+    cronScheduleTimezone = graphene.Field(graphene.String)
 
     class Meta:
         name = "FreshnessPolicy"
@@ -24,4 +25,5 @@ class GrapheneFreshnessPolicy(graphene.ObjectType):
         super().__init__(
             maximumLagMinutes=freshness_policy.maximum_lag_minutes,
             cronSchedule=freshness_policy.cron_schedule,
+            cronScheduleTimezone=freshness_policy.cron_schedule_timezone,
         )
