@@ -5,7 +5,9 @@ import graphene
 from dagster._core.instance import DagsterInstance
 from dagster._core.launcher.base import RunLauncher
 from dagster._core.storage.captured_log_manager import CapturedLogManager
+from dagster._daemon.asset_daemon import get_auto_materialize_paused
 from dagster._daemon.types import DaemonStatus
+from dagster._utils.concurrency import ConcurrencyKeyInfo
 
 from .errors import GraphenePythonError
 from .util import ResolveInfo, non_null_list
@@ -87,7 +89,34 @@ class GrapheneDaemonHealth(graphene.ObjectType):
         ]
 
 
+class GrapheneConcurrencyKeyInfo(graphene.ObjectType):
+    concurrencyKey = graphene.NonNull(graphene.String)
+    slotCount = graphene.NonNull(graphene.Int)
+    activeSlotCount = graphene.NonNull(graphene.Int)
+    activeRunIds = non_null_list(graphene.String)
+    pendingStepCount = graphene.NonNull(graphene.Int)
+    pendingStepRunIds = non_null_list(graphene.String)
+    assignedStepCount = graphene.NonNull(graphene.Int)
+    assignedStepRunIds = non_null_list(graphene.String)
+
+    class Meta:
+        name = "ConcurrencyKeyInfo"
+
+    def __init__(self, concurrency_key_info: ConcurrencyKeyInfo):
+        super().__init__(
+            concurrencyKey=concurrency_key_info.concurrency_key,
+            slotCount=concurrency_key_info.slot_count,
+            activeSlotCount=concurrency_key_info.active_slot_count,
+            activeRunIds=list(concurrency_key_info.active_run_ids),
+            pendingStepCount=concurrency_key_info.pending_step_count,
+            pendingStepRunIds=list(concurrency_key_info.pending_run_ids),
+            assignedStepCount=concurrency_key_info.assigned_step_count,
+            assignedStepRunIds=list(concurrency_key_info.assigned_run_ids),
+        )
+
+
 class GrapheneInstance(graphene.ObjectType):
+    id = graphene.NonNull(graphene.String)
     info = graphene.Field(graphene.String)
     runLauncher = graphene.Field(GrapheneRunLauncher)
     runQueuingSupported = graphene.NonNull(graphene.Boolean)
@@ -95,6 +124,8 @@ class GrapheneInstance(graphene.ObjectType):
     daemonHealth = graphene.NonNull(GrapheneDaemonHealth)
     hasInfo = graphene.NonNull(graphene.Boolean)
     hasCapturedLogManager = graphene.NonNull(graphene.Boolean)
+    autoMaterializePaused = graphene.NonNull(graphene.Boolean)
+    concurrencyLimits = non_null_list(GrapheneConcurrencyKeyInfo)
 
     class Meta:
         name = "Instance"
@@ -103,6 +134,9 @@ class GrapheneInstance(graphene.ObjectType):
         super().__init__()
         self._instance = check.inst_param(instance, "instance", DagsterInstance)
 
+    def resolve_id(self, _graphene_info: ResolveInfo):
+        return "Instance"
+
     def resolve_hasInfo(self, graphene_info: ResolveInfo) -> bool:
         return graphene_info.context.show_instance_config
 
@@ -129,3 +163,13 @@ class GrapheneInstance(graphene.ObjectType):
 
     def resolve_hasCapturedLogManager(self, _graphene_info: ResolveInfo):
         return isinstance(self._instance.compute_log_manager, CapturedLogManager)
+
+    def resolve_autoMaterializePaused(self, _graphene_info: ResolveInfo):
+        return get_auto_materialize_paused(self._instance)
+
+    def resolve_concurrencyLimits(self, _graphene_info: ResolveInfo):
+        res = []
+        for key in self._instance.event_log_storage.get_concurrency_keys():
+            key_info = self._instance.event_log_storage.get_concurrency_info(key)
+            res.append(GrapheneConcurrencyKeyInfo(key_info))
+        return res
