@@ -5,11 +5,16 @@ from typing import Optional, Union
 import dagster._check as check
 import graphene
 import pendulum
-from dagster._core.definitions.run_request import RunRequest
+from dagster._core.definitions.run_request import (
+    AddDynamicPartitionsRequest,
+    DeleteDynamicPartitionsRequest,
+    RunRequest,
+)
 from dagster._core.definitions.schedule_definition import ScheduleExecutionData
 from dagster._core.definitions.selector import ScheduleSelector, SensorSelector
 from dagster._core.definitions.sensor_definition import SensorExecutionData
 from dagster._core.scheduler.instigation import (
+    DynamicPartitionsRequestResult,
     InstigatorState,
     InstigatorTick,
     InstigatorType,
@@ -17,13 +22,15 @@ from dagster._core.scheduler.instigation import (
     SensorInstigatorData,
     TickStatus,
 )
-from dagster._core.storage.pipeline_run import DagsterRun, RunsFilter
+from dagster._core.storage.dagster_run import DagsterRun, RunsFilter
 from dagster._core.storage.tags import REPOSITORY_LABEL_TAG, TagType, get_tag_type
 from dagster._core.workspace.permissions import Permissions
 from dagster._seven.compat.pendulum import to_timezone
 from dagster._utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
 from dagster._utils.yaml_utils import dump_run_config_yaml
 
+from dagster_graphql.schema.asset_key import GrapheneAssetKey
+
 from ..implementation.fetch_instigators import get_tick_log_events
 from ..implementation.fetch_schedules import get_schedule_next_tick
 from ..implementation.fetch_sensors import get_sensor_next_tick
@@ -125,6 +132,99 @@ class GrapheneInstigationEventConnection(graphene.ObjectType):
     hasMore = graphene.NonNull(graphene.Boolean)
 
 
+class GrapheneDynamicPartitionsRequestType(graphene.Enum):
+    ADD_PARTITIONS = "ADD_PARTITIONS"
+    DELETE_PARTITIONS = "DELETE_PARTITIONS"
+
+    class Meta:
+        name = "DynamicPartitionsRequestType"
+
+
+class DynamicPartitionsRequestMixin:
+    # Mixin this class to implement DynamicPartitionsRequest
+    #
+    # Graphene has some strange properties that make it so that you cannot
+    # implement ABCs nor use properties in an overridable way. So the way
+    # the mixin works is that the target classes have to have a method
+    # get_dynamic_partitions_request()
+    partitionKeys = graphene.List(graphene.NonNull(graphene.String))
+    partitionsDefName = graphene.NonNull(graphene.String)
+    type = graphene.NonNull(GrapheneDynamicPartitionsRequestType)
+
+    class Meta:
+        name = "DynamicPartitionRequestMixin"
+
+    def get_dynamic_partitions_request(
+        self,
+    ) -> Union[AddDynamicPartitionsRequest, DeleteDynamicPartitionsRequest,]:
+        raise NotImplementedError()
+
+    def resolve_partitionKeys(self, _graphene_info: ResolveInfo):
+        return self.get_dynamic_partitions_request().partition_keys
+
+    def resolve_partitionsDefName(self, _graphene_info: ResolveInfo):
+        return self.get_dynamic_partitions_request().partitions_def_name
+
+    def resolve_type(self, _graphene_info: ResolveInfo):
+        return (
+            GrapheneDynamicPartitionsRequestType.ADD_PARTITIONS
+            if isinstance(self.get_dynamic_partitions_request(), AddDynamicPartitionsRequest)
+            else GrapheneDynamicPartitionsRequestType.DELETE_PARTITIONS
+        )
+
+
+class GrapheneDynamicPartitionsRequest(DynamicPartitionsRequestMixin, graphene.ObjectType):
+    class Meta:
+        name = "DynamicPartitionRequest"
+
+    def __init__(
+        self,
+        dynamic_partition_request: Union[
+            AddDynamicPartitionsRequest, DeleteDynamicPartitionsRequest
+        ],
+    ):
+        super().__init__()
+        self._dynamic_partitions_request = dynamic_partition_request
+
+    def get_dynamic_partitions_request(
+        self,
+    ) -> Union[AddDynamicPartitionsRequest, DeleteDynamicPartitionsRequest,]:
+        return self._dynamic_partitions_request
+
+
+class GrapheneDynamicPartitionsRequestResult(DynamicPartitionsRequestMixin, graphene.ObjectType):
+    class Meta:
+        name = "DynamicPartitionsRequestResult"
+
+    skippedPartitionKeys = non_null_list(graphene.String)
+
+    def __init__(self, dynamic_partitions_request_result: DynamicPartitionsRequestResult):
+        super().__init__()
+        self._dynamic_partitions_request_result = dynamic_partitions_request_result
+
+    def get_dynamic_partitions_request(
+        self,
+    ) -> Union[AddDynamicPartitionsRequest, DeleteDynamicPartitionsRequest]:
+        if self._dynamic_partitions_request_result.added_partitions is not None:
+            return AddDynamicPartitionsRequest(
+                partition_keys=self._dynamic_partitions_request_result.added_partitions,
+                partitions_def_name=self._dynamic_partitions_request_result.partitions_def_name,
+            )
+        elif self._dynamic_partitions_request_result.deleted_partitions is not None:
+            return DeleteDynamicPartitionsRequest(
+                partition_keys=self._dynamic_partitions_request_result.deleted_partitions,
+                partitions_def_name=self._dynamic_partitions_request_result.partitions_def_name,
+            )
+        else:
+            check.failed(
+                "Unexpected dynamic_partitions_request_result"
+                f" {self._dynamic_partitions_request_result}"
+            )
+
+    def resolve_skippedPartitionKeys(self, _graphene_info: ResolveInfo):
+        return self._dynamic_partitions_request_result.skipped_partitions
+
+
 class GrapheneInstigationTick(graphene.ObjectType):
     id = graphene.NonNull(graphene.ID)
     status = graphene.NonNull(GrapheneInstigationTickStatus)
@@ -138,6 +238,7 @@ class GrapheneInstigationTick(graphene.ObjectType):
     originRunIds = non_null_list(graphene.String)
     logKey = graphene.List(graphene.NonNull(graphene.String))
     logEvents = graphene.Field(graphene.NonNull(GrapheneInstigationEventConnection))
+    dynamicPartitionsRequestResults = non_null_list(GrapheneDynamicPartitionsRequestResult)
 
     class Meta:
         name = "InstigationTick"
@@ -178,6 +279,12 @@ class GrapheneInstigationTick(graphene.ObjectType):
     def resolve_logEvents(self, graphene_info: ResolveInfo):
         return get_tick_log_events(graphene_info, self._tick)
 
+    def resolve_dynamicPartitionsRequestResults(self, _):
+        return [
+            GrapheneDynamicPartitionsRequestResult(request_result)
+            for request_result in self._tick.dynamic_partitions_request_results
+        ]
+
 
 class GrapheneDryRunInstigationTick(graphene.ObjectType):
     timestamp = graphene.Float()
@@ -265,15 +372,21 @@ class GrapheneDryRunInstigationTick(graphene.ObjectType):
 
 
 class GrapheneTickEvaluation(graphene.ObjectType):
+    dynamicPartitionsRequests = graphene.List(graphene.NonNull(GrapheneDynamicPartitionsRequest))
     runRequests = graphene.List(lambda: graphene.NonNull(GrapheneRunRequest))
     skipReason = graphene.String()
     error = graphene.Field(GraphenePythonError)
     cursor = graphene.String()
 
+    _execution_data: Union[ScheduleExecutionData, SensorExecutionData, SerializableErrorInfo]
+
     class Meta:
         name = "TickEvaluation"
 
-    def __init__(self, execution_data):
+    def __init__(
+        self,
+        execution_data: Union[ScheduleExecutionData, SensorExecutionData, SerializableErrorInfo],
+    ):
         check.inst_param(
             execution_data,
             "execution_data",
@@ -289,13 +402,25 @@ class GrapheneTickEvaluation(graphene.ObjectType):
             if not isinstance(execution_data, SerializableErrorInfo)
             else None
         )
+        self._execution_data = execution_data
         self._run_requests = (
             execution_data.run_requests
             if not isinstance(execution_data, SerializableErrorInfo)
             else None
         )
+
+        self._dynamic_partitions_requests = (
+            execution_data.dynamic_partitions_requests
+            if isinstance(execution_data, SensorExecutionData)
+            else None
+        )
+
         cursor = execution_data.cursor if isinstance(execution_data, SensorExecutionData) else None
-        super().__init__(skipReason=skip_reason, error=error, cursor=cursor)
+        super().__init__(
+            skipReason=skip_reason,
+            error=error,
+            cursor=cursor,
+        )
 
     def resolve_runRequests(self, _graphene_info: ResolveInfo):
         if not self._run_requests:
@@ -303,11 +428,23 @@ class GrapheneTickEvaluation(graphene.ObjectType):
 
         return [GrapheneRunRequest(run_request) for run_request in self._run_requests]
 
+    def resolve_dynamicPartitionsRequests(self, _graphene_info: ResolveInfo):
+        if not self._dynamic_partitions_requests:
+            return self._dynamic_partitions_requests
+
+        return [
+            GrapheneDynamicPartitionsRequest(request)
+            for request in self._dynamic_partitions_requests
+        ]
+
 
 class GrapheneRunRequest(graphene.ObjectType):
     runKey = graphene.String()
     tags = non_null_list(GraphenePipelineTag)
     runConfigYaml = graphene.NonNull(graphene.String)
+    assetSelection = graphene.List(graphene.NonNull(GrapheneAssetKey))
+
+    _run_request: RunRequest
 
     class Meta:
         name = "RunRequest"
@@ -326,6 +463,14 @@ class GrapheneRunRequest(graphene.ObjectType):
     def resolve_runConfigYaml(self, _graphene_info: ResolveInfo):
         return dump_run_config_yaml(self._run_request.run_config)
 
+    def resolve_assetSelection(self, _graphene_info: ResolveInfo):
+        if self._run_request.asset_selection:
+            return [
+                GrapheneAssetKey(path=asset_key.path)
+                for asset_key in self._run_request.asset_selection
+            ]
+        return None
+
 
 class GrapheneDryRunInstigationTicks(graphene.ObjectType):
     results = non_null_list(GrapheneDryRunInstigationTick)
