@@ -4,11 +4,12 @@ import dagster._check as check
 import graphene
 from dagster._core.definitions.time_window_partitions import PartitionRangeStatus
 from dagster._core.events import DagsterEventType
-from dagster._core.host_representation.external import ExternalExecutionPlan, ExternalPipeline
-from dagster._core.host_representation.external_data import ExternalPresetData
-from dagster._core.storage.pipeline_run import (
+from dagster._core.host_representation.external import ExternalExecutionPlan, ExternalJob
+from dagster._core.host_representation.external_data import DEFAULT_MODE_NAME, ExternalPresetData
+from dagster._core.host_representation.represented import RepresentedJob
+from dagster._core.storage.dagster_run import (
+    DagsterRunStatsSnapshot,
     DagsterRunStatus,
-    PipelineRunStatsSnapshot,
     RunRecord,
     RunsFilter,
 )
@@ -22,7 +23,7 @@ from dagster_graphql.schema.metadata import GrapheneMetadataEntry
 
 from ...implementation.events import from_event_record
 from ...implementation.fetch_assets import get_assets_for_run_id, get_unique_asset_id
-from ...implementation.fetch_pipelines import get_pipeline_reference_or_raise
+from ...implementation.fetch_pipelines import get_job_reference_or_raise
 from ...implementation.fetch_runs import get_runs, get_stats, get_step_stats
 from ...implementation.fetch_schedules import get_schedules_for_pipeline
 from ...implementation.fetch_sensors import get_sensors_for_pipeline
@@ -88,7 +89,6 @@ GraphenePartitionRangeStatus = graphene.Enum.from_enum(PartitionRangeStatus)
 
 
 class GrapheneTimePartitionRange(graphene.ObjectType):
-    status = graphene.NonNull(GraphenePartitionRangeStatus)
     startTime = graphene.NonNull(graphene.Float)
     endTime = graphene.NonNull(graphene.Float)
     startKey = graphene.NonNull(graphene.String)
@@ -98,30 +98,37 @@ class GrapheneTimePartitionRange(graphene.ObjectType):
         name = "TimePartitionRange"
 
 
-class GrapheneTimePartitions(graphene.ObjectType):
-    ranges = non_null_list(GrapheneTimePartitionRange)
+class GrapheneTimePartitionRangeStatus(GrapheneTimePartitionRange):
+    status = graphene.NonNull(GraphenePartitionRangeStatus)
 
     class Meta:
-        name = "TimePartitions"
+        name = "TimePartitionRangeStatus"
 
 
-class GrapheneDefaultPartitions(graphene.ObjectType):
+class GrapheneTimePartitionStatuses(graphene.ObjectType):
+    ranges = non_null_list(GrapheneTimePartitionRangeStatus)
+
+    class Meta:
+        name = "TimePartitionStatuses"
+
+
+class GrapheneDefaultPartitionStatuses(graphene.ObjectType):
     materializedPartitions = non_null_list(graphene.String)
     failedPartitions = non_null_list(graphene.String)
     unmaterializedPartitions = non_null_list(graphene.String)
     materializingPartitions = non_null_list(graphene.String)
 
     class Meta:
-        name = "DefaultPartitions"
+        name = "DefaultPartitionStatuses"
 
 
 class GraphenePartitionStatus1D(graphene.Union):
     class Meta:
-        types = (GrapheneTimePartitions, GrapheneDefaultPartitions)
+        types = (GrapheneTimePartitionStatuses, GrapheneDefaultPartitionStatuses)
         name = "PartitionStatus1D"
 
 
-class GrapheneMultiPartitionRange(graphene.ObjectType):
+class GrapheneMultiPartitionRangeStatuses(graphene.ObjectType):
     """The primary dimension of a multipartitioned asset is the time-partitioned dimension.
     If both dimensions of the asset are static or time-partitioned, the primary dimension is
     the first defined dimension.
@@ -134,20 +141,24 @@ class GrapheneMultiPartitionRange(graphene.ObjectType):
     secondaryDim = graphene.NonNull(GraphenePartitionStatus1D)
 
     class Meta:
-        name = "MaterializedPartitionRange2D"
+        name = "MaterializedPartitionRangeStatuses2D"
 
 
-class GrapheneMultiPartitions(graphene.ObjectType):
-    ranges = non_null_list(GrapheneMultiPartitionRange)
+class GrapheneMultiPartitionStatuses(graphene.ObjectType):
+    ranges = non_null_list(GrapheneMultiPartitionRangeStatuses)
     primaryDimensionName = graphene.NonNull(graphene.String)
 
     class Meta:
-        name = "MultiPartitions"
+        name = "MultiPartitionStatuses"
 
 
 class GrapheneAssetPartitionStatuses(graphene.Union):
     class Meta:
-        types = (GrapheneDefaultPartitions, GrapheneMultiPartitions, GrapheneTimePartitions)
+        types = (
+            GrapheneDefaultPartitionStatuses,
+            GrapheneMultiPartitionStatuses,
+            GrapheneTimePartitionStatuses,
+        )
         name = "AssetPartitionStatuses"
 
 
@@ -372,20 +383,20 @@ class GrapheneRun(graphene.ObjectType):
 
     def __init__(self, record: RunRecord):
         check.inst_param(record, "record", RunRecord)
-        pipeline_run = record.dagster_run
+        dagster_run = record.dagster_run
         super().__init__(
-            runId=pipeline_run.run_id,
-            status=pipeline_run.status.value,
-            mode=pipeline_run.mode,
+            runId=dagster_run.run_id,
+            status=dagster_run.status.value,
+            mode=DEFAULT_MODE_NAME,
         )
-        self._pipeline_run = pipeline_run
+        self.dagster_run = dagster_run
         self._run_record = record
-        self._run_stats: Optional[PipelineRunStatsSnapshot] = None
+        self._run_stats: Optional[DagsterRunStatsSnapshot] = None
 
     def _get_permission_value(self, permission: Permissions, graphene_info: ResolveInfo) -> bool:
         location_name = (
-            self._pipeline_run.external_pipeline_origin.location_name
-            if self._pipeline_run.external_pipeline_origin
+            self.dagster_run.external_job_origin.location_name
+            if self.dagster_run.external_job_origin
             else None
         )
 
@@ -405,49 +416,49 @@ class GrapheneRun(graphene.ObjectType):
         return self._get_permission_value(Permissions.DELETE_PIPELINE_RUN, graphene_info)
 
     def resolve_id(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.run_id
+        return self.dagster_run.run_id
 
     def resolve_repositoryOrigin(self, _graphene_info: ResolveInfo):
         return (
             GrapheneRepositoryOrigin(
-                self._pipeline_run.external_pipeline_origin.external_repository_origin
+                self.dagster_run.external_job_origin.external_repository_origin
             )
-            if self._pipeline_run.external_pipeline_origin
+            if self.dagster_run.external_job_origin
             else None
         )
 
     def resolve_pipeline(self, graphene_info: ResolveInfo):
-        return get_pipeline_reference_or_raise(graphene_info, self._pipeline_run)
+        return get_job_reference_or_raise(graphene_info, self.dagster_run)
 
     def resolve_pipelineName(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.pipeline_name
+        return self.dagster_run.job_name
 
     def resolve_jobName(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.pipeline_name
+        return self.dagster_run.job_name
 
     def resolve_solidSelection(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.solid_selection
+        return self.dagster_run.op_selection
 
     def resolve_assetSelection(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.asset_selection
+        return self.dagster_run.asset_selection
 
     def resolve_resolvedOpSelection(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.solids_to_execute
+        return self.dagster_run.resolved_op_selection
 
     def resolve_pipelineSnapshotId(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.pipeline_snapshot_id
+        return self.dagster_run.job_snapshot_id
 
     def resolve_parentPipelineSnapshotId(self, graphene_info: ResolveInfo):
-        pipeline_snapshot_id = self._pipeline_run.pipeline_snapshot_id
-        if (
-            pipeline_snapshot_id is not None
-            and graphene_info.context.instance.has_pipeline_snapshot(pipeline_snapshot_id)
+        pipeline_snapshot_id = self.dagster_run.job_snapshot_id
+        if pipeline_snapshot_id is not None and graphene_info.context.instance.has_job_snapshot(
+            pipeline_snapshot_id
         ):
-            snapshot = graphene_info.context.instance.get_pipeline_snapshot(pipeline_snapshot_id)
+            snapshot = graphene_info.context.instance.get_job_snapshot(pipeline_snapshot_id)
             if snapshot.lineage_snapshot is not None:
                 return snapshot.lineage_snapshot.parent_snapshot_id
         return None
 
+    @capture_error
     def resolve_stats(self, graphene_info: ResolveInfo):
         return get_stats(graphene_info, self.run_id)
 
@@ -464,16 +475,13 @@ class GrapheneRun(graphene.ObjectType):
         return from_captured_log_data(log_data)
 
     def resolve_executionPlan(self, graphene_info: ResolveInfo):
-        if not (
-            self._pipeline_run.execution_plan_snapshot_id
-            and self._pipeline_run.pipeline_snapshot_id
-        ):
+        if not (self.dagster_run.execution_plan_snapshot_id and self.dagster_run.job_snapshot_id):
             return None
 
         instance = graphene_info.context.instance
 
         execution_plan_snapshot = instance.get_execution_plan_snapshot(
-            self._pipeline_run.execution_plan_snapshot_id
+            self.dagster_run.execution_plan_snapshot_id
         )
         return (
             GrapheneExecutionPlan(
@@ -484,26 +492,26 @@ class GrapheneRun(graphene.ObjectType):
         )
 
     def resolve_stepKeysToExecute(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.step_keys_to_execute
+        return self.dagster_run.step_keys_to_execute
 
     def resolve_runConfigYaml(self, _graphene_info: ResolveInfo):
-        return dump_run_config_yaml(self._pipeline_run.run_config)
+        return dump_run_config_yaml(self.dagster_run.run_config)
 
     def resolve_runConfig(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.run_config
+        return self.dagster_run.run_config
 
     def resolve_tags(self, _graphene_info: ResolveInfo):
         return [
             GraphenePipelineTag(key=key, value=value)
-            for key, value in self._pipeline_run.tags.items()
+            for key, value in self.dagster_run.tags.items()
             if get_tag_type(key) != TagType.HIDDEN
         ]
 
     def resolve_rootRunId(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.root_run_id
+        return self.dagster_run.root_run_id
 
     def resolve_parentRunId(self, _graphene_info: ResolveInfo):
-        return self._pipeline_run.parent_run_id
+        return self.dagster_run.parent_run_id
 
     @property
     def run_id(self):
@@ -511,11 +519,11 @@ class GrapheneRun(graphene.ObjectType):
 
     def resolve_canTerminate(self, _graphene_info: ResolveInfo):
         # short circuit if the pipeline run is in a terminal state
-        if self._pipeline_run.is_finished:
+        if self.dagster_run.is_finished:
             return False
         return (
-            self._pipeline_run.status == DagsterRunStatus.QUEUED
-            or self._pipeline_run.status == DagsterRunStatus.STARTED
+            self.dagster_run.status == DagsterRunStatus.QUEUED
+            or self.dagster_run.status == DagsterRunStatus.STARTED
         )
 
     def resolve_assets(self, graphene_info: ResolveInfo):
@@ -534,7 +542,7 @@ class GrapheneRun(graphene.ObjectType):
         conn = graphene_info.context.instance.get_records_for_run(self.run_id, cursor=afterCursor)
         return GrapheneEventConnection(
             events=[
-                from_event_record(record.event_log_entry, self._pipeline_run.pipeline_name)
+                from_event_record(record.event_log_entry, self.dagster_run.job_name)
                 for record in conn.records
             ],
             cursor=conn.cursor,
@@ -549,7 +557,7 @@ class GrapheneRun(graphene.ObjectType):
     def resolve_startTime(self, graphene_info: ResolveInfo):
         run_record = self._get_run_record(graphene_info.context.instance)
         # If a user has not migrated in 0.13.15, then run_record will not have start_time and end_time. So it will be necessary to fill this data using the run_stats. Since we potentially make this call multiple times, we cache the result.
-        if run_record.start_time is None and self._pipeline_run.status in STARTED_STATUSES:
+        if run_record.start_time is None and self.dagster_run.status in STARTED_STATUSES:
             # Short-circuit if pipeline failed to start, so it has an end time but no start time
             if run_record.end_time is not None:
                 return run_record.end_time
@@ -565,7 +573,7 @@ class GrapheneRun(graphene.ObjectType):
 
     def resolve_endTime(self, graphene_info: ResolveInfo):
         run_record = self._get_run_record(graphene_info.context.instance)
-        if run_record.end_time is None and self._pipeline_run.status in COMPLETED_STATUSES:
+        if run_record.end_time is None and self.dagster_run.status in COMPLETED_STATUSES:
             if self._run_stats is None or self._run_stats.end_time is None:
                 self._run_stats = graphene_info.context.instance.get_run_stats(self.runId)
             return self._run_stats.end_time
@@ -582,7 +590,7 @@ class GrapheneIPipelineSnapshotMixin:
     # Graphene has some strange properties that make it so that you cannot
     # implement ABCs nor use properties in an overridable way. So the way
     # the mixin works is that the target classes have to have a method
-    # get_represented_pipeline()
+    # get_represented_job()
     #
     name = graphene.NonNull(graphene.String)
     description = graphene.String()
@@ -617,27 +625,27 @@ class GrapheneIPipelineSnapshotMixin:
     class Meta:
         name = "IPipelineSnapshotMixin"
 
-    def get_represented_pipeline(self):
+    def get_represented_job(self) -> RepresentedJob:
         raise NotImplementedError()
 
     def resolve_pipeline_snapshot_id(self, _graphene_info: ResolveInfo):
-        return self.get_represented_pipeline().identifying_pipeline_snapshot_id
+        return self.get_represented_job().identifying_job_snapshot_id
 
     def resolve_id(self, _graphene_info: ResolveInfo):
-        return self.get_represented_pipeline().identifying_pipeline_snapshot_id
+        return self.get_represented_job().identifying_job_snapshot_id
 
     def resolve_name(self, _graphene_info: ResolveInfo):
-        return self.get_represented_pipeline().name
+        return self.get_represented_job().name
 
     def resolve_description(self, _graphene_info: ResolveInfo):
-        return self.get_represented_pipeline().description
+        return self.get_represented_job().description
 
     def resolve_dagster_types(self, _graphene_info: ResolveInfo):
-        represented_pipeline = self.get_represented_pipeline()
+        represented_pipeline = self.get_represented_job()
         return sorted(
             list(
                 map(
-                    lambda dt: to_dagster_type(represented_pipeline.pipeline_snapshot, dt.key),
+                    lambda dt: to_dagster_type(represented_pipeline.job_snapshot, dt.key),
                     [t for t in represented_pipeline.dagster_type_snaps if t.name],
                 )
             ),
@@ -648,7 +656,7 @@ class GrapheneIPipelineSnapshotMixin:
     def resolve_dagster_type_or_error(
         self, _graphene_info: ResolveInfo, dagsterTypeName: str
     ) -> GrapheneDagsterTypeUnion:
-        represented_pipeline = self.get_represented_pipeline()
+        represented_pipeline = self.get_represented_job()
 
         if not represented_pipeline.has_dagster_type_named(dagsterTypeName):
             raise UserFacingGraphQLError(
@@ -656,23 +664,23 @@ class GrapheneIPipelineSnapshotMixin:
             )
 
         return to_dagster_type(
-            represented_pipeline.pipeline_snapshot,
+            represented_pipeline.job_snapshot,
             represented_pipeline.get_dagster_type_by_name(dagsterTypeName).key,
         )
 
     def resolve_solids(self, _graphene_info: ResolveInfo):
-        represented_pipeline = self.get_represented_pipeline()
+        represented_pipeline = self.get_represented_job()
         return build_solids(
             represented_pipeline,
             represented_pipeline.dep_structure_index,
         )
 
     def resolve_modes(self, _graphene_info: ResolveInfo):
-        represented_pipeline = self.get_represented_pipeline()
+        represented_pipeline = self.get_represented_job()
         return [
             GrapheneMode(
                 represented_pipeline.config_schema_snapshot,
-                represented_pipeline.identifying_pipeline_snapshot_id,
+                represented_pipeline.identifying_job_snapshot_id,
                 mode_def_snap,
             )
             for mode_def_snap in sorted(
@@ -683,12 +691,12 @@ class GrapheneIPipelineSnapshotMixin:
     def resolve_solid_handle(
         self, _graphene_info: ResolveInfo, handleID: str
     ) -> Optional[GrapheneSolidHandle]:
-        return build_solid_handles(self.get_represented_pipeline()).get(handleID)
+        return build_solid_handles(self.get_represented_job()).get(handleID)
 
     def resolve_solid_handles(
         self, _graphene_info: ResolveInfo, parentHandleID: Optional[str] = None
     ) -> Sequence[GrapheneSolidHandle]:
-        handles = build_solid_handles(self.get_represented_pipeline())
+        handles = build_solid_handles(self.get_represented_job())
 
         if parentHandleID == "":
             handles = {key: handle for key, handle in handles.items() if not handle.parent}
@@ -702,37 +710,37 @@ class GrapheneIPipelineSnapshotMixin:
         return [handles[key] for key in sorted(handles)]
 
     def resolve_tags(self, _graphene_info: ResolveInfo):
-        represented_pipeline = self.get_represented_pipeline()
+        represented_pipeline = self.get_represented_job()
         return [
             GraphenePipelineTag(key=key, value=value)
-            for key, value in represented_pipeline.pipeline_snapshot.tags.items()
+            for key, value in represented_pipeline.job_snapshot.tags.items()
         ]
 
     def resolve_metadata_entries(self, _graphene_info: ResolveInfo) -> List[GrapheneMetadataEntry]:
-        represented_pipeline = self.get_represented_pipeline()
-        return list(iterate_metadata_entries(represented_pipeline.pipeline_snapshot.metadata))
+        represented_pipeline = self.get_represented_job()
+        return list(iterate_metadata_entries(represented_pipeline.job_snapshot.metadata))
 
     def resolve_solidSelection(self, _graphene_info: ResolveInfo):
-        return self.get_represented_pipeline().solid_selection
+        return self.get_represented_job().op_selection
 
     def resolve_runs(
         self, graphene_info: ResolveInfo, cursor: Optional[str] = None, limit: Optional[int] = None
     ) -> Sequence[GrapheneRun]:
-        pipeline = self.get_represented_pipeline()
-        if isinstance(pipeline, ExternalPipeline):
+        pipeline = self.get_represented_job()
+        if isinstance(pipeline, ExternalJob):
             runs_filter = RunsFilter(
-                pipeline_name=pipeline.name,
+                job_name=pipeline.name,
                 tags={
                     REPOSITORY_LABEL_TAG: pipeline.get_external_origin().external_repository_origin.get_label()
                 },
             )
         else:
-            runs_filter = RunsFilter(pipeline_name=pipeline.name)
+            runs_filter = RunsFilter(job_name=pipeline.name)
         return get_runs(graphene_info, runs_filter, cursor, limit)
 
     def resolve_schedules(self, graphene_info: ResolveInfo):
-        represented_pipeline = self.get_represented_pipeline()
-        if not isinstance(represented_pipeline, ExternalPipeline):
+        represented_pipeline = self.get_represented_job()
+        if not isinstance(represented_pipeline, ExternalJob):
             # this is an historical pipeline snapshot, so there are not any associated running
             # schedules
             return []
@@ -742,8 +750,8 @@ class GrapheneIPipelineSnapshotMixin:
         return schedules
 
     def resolve_sensors(self, graphene_info: ResolveInfo):
-        represented_pipeline = self.get_represented_pipeline()
-        if not isinstance(represented_pipeline, ExternalPipeline):
+        represented_pipeline = self.get_represented_job()
+        if not isinstance(represented_pipeline, ExternalJob):
             # this is an historical pipeline snapshot, so there are not any associated running
             # sensors
             return []
@@ -753,14 +761,14 @@ class GrapheneIPipelineSnapshotMixin:
         return sensors
 
     def resolve_parent_snapshot_id(self, _graphene_info: ResolveInfo):
-        lineage_snapshot = self.get_represented_pipeline().pipeline_snapshot.lineage_snapshot
+        lineage_snapshot = self.get_represented_job().job_snapshot.lineage_snapshot
         if lineage_snapshot:
             return lineage_snapshot.parent_snapshot_id
         else:
             return None
 
     def resolve_graph_name(self, _graphene_info: ResolveInfo):
-        return self.get_represented_pipeline().get_graph_name()
+        return self.get_represented_job().get_graph_name()
 
 
 class GrapheneIPipelineSnapshot(graphene.Interface):
@@ -812,13 +820,13 @@ class GraphenePipelinePreset(graphene.ObjectType):
         self._active_preset_data = check.inst_param(
             active_preset_data, "active_preset_data", ExternalPresetData
         )
-        self._pipeline_name = check.str_param(pipeline_name, "pipeline_name")
+        self._job_name = check.str_param(pipeline_name, "pipeline_name")
 
     def resolve_name(self, _graphene_info: ResolveInfo):
         return self._active_preset_data.name
 
     def resolve_solidSelection(self, _graphene_info: ResolveInfo):
-        return self._active_preset_data.solid_selection
+        return self._active_preset_data.op_selection
 
     def resolve_runConfigYaml(self, _graphene_info: ResolveInfo):
         return dump_run_config_yaml(self._active_preset_data.run_config) or ""
@@ -845,11 +853,11 @@ class GraphenePipeline(GrapheneIPipelineSnapshotMixin, graphene.ObjectType):
         interfaces = (GrapheneSolidContainer, GrapheneIPipelineSnapshot)
         name = "Pipeline"
 
-    def __init__(self, external_pipeline, batch_loader=None):
+    def __init__(
+        self, external_job: ExternalJob, batch_loader: Optional[RepositoryScopedBatchLoader] = None
+    ):
         super().__init__()
-        self._external_pipeline = check.inst_param(
-            external_pipeline, "external_pipeline", ExternalPipeline
-        )
+        self._external_job = check.inst_param(external_job, "external_job", ExternalJob)
         # optional run loader, provided by a parent GrapheneRepository object that instantiates
         # multiple pipelines
         self._batch_loader = check.opt_inst_param(
@@ -857,30 +865,30 @@ class GraphenePipeline(GrapheneIPipelineSnapshotMixin, graphene.ObjectType):
         )
 
     def resolve_id(self, _graphene_info: ResolveInfo):
-        return self._external_pipeline.get_external_origin_id()
+        return self._external_job.get_external_origin_id()
 
-    def get_represented_pipeline(self):
-        return self._external_pipeline
+    def get_represented_job(self) -> RepresentedJob:
+        return self._external_job
 
     def resolve_presets(self, _graphene_info: ResolveInfo):
         return [
-            GraphenePipelinePreset(preset, self._external_pipeline.name)
-            for preset in sorted(self._external_pipeline.active_presets, key=lambda item: item.name)
+            GraphenePipelinePreset(preset, self._external_job.name)
+            for preset in sorted(self._external_job.active_presets, key=lambda item: item.name)
         ]
 
     def resolve_isJob(self, _graphene_info: ResolveInfo):
-        return self._external_pipeline.is_job
+        return True
 
     def resolve_isAssetJob(self, graphene_info: ResolveInfo):
-        handle = self._external_pipeline.repository_handle
+        handle = self._external_job.repository_handle
         location = graphene_info.context.get_code_location(handle.location_name)
         repository = location.get_repository(handle.repository_name)
-        return bool(repository.get_external_asset_nodes(self._external_pipeline.name))
+        return bool(repository.get_external_asset_nodes(self._external_job.name))
 
     def resolve_repository(self, graphene_info: ResolveInfo):
         from ..external import GrapheneRepository
 
-        handle = self._external_pipeline.repository_handle
+        handle = self._external_job.repository_handle
         location = graphene_info.context.get_code_location(handle.location_name)
         return GrapheneRepository(
             graphene_info.context.instance,
@@ -893,9 +901,7 @@ class GraphenePipeline(GrapheneIPipelineSnapshotMixin, graphene.ObjectType):
     ) -> Sequence[GrapheneRun]:
         # override the implementation to use the batch run loader
         if not cursor and limit and self._batch_loader:
-            records = self._batch_loader.get_run_records_for_job(
-                self._external_pipeline.name, limit
-            )
+            records = self._batch_loader.get_run_records_for_job(self._external_job.name, limit)
             return [GrapheneRun(record) for record in records]
 
         # otherwise, fall back to the default implementation
@@ -908,11 +914,9 @@ class GrapheneJob(GraphenePipeline):
         name = "Job"
 
     # doesn't inherit from base class
-    def __init__(self, external_pipeline, batch_loader=None):
+    def __init__(self, external_job, batch_loader=None):
         super().__init__()
-        self._external_pipeline = check.inst_param(
-            external_pipeline, "external_pipeline", ExternalPipeline
-        )
+        self._external_job = check.inst_param(external_job, "external_job", ExternalJob)
         # optional run loader, provided by a parent GrapheneRepository object that instantiates
         # multiple pipelines
         self._batch_loader = check.opt_inst_param(
@@ -939,7 +943,7 @@ class GrapheneGraph(graphene.ObjectType):
 
     def __init__(self, external_pipeline, solid_handle_id=None):
         self._external_pipeline = check.inst_param(
-            external_pipeline, "external_pipeline", ExternalPipeline
+            external_pipeline, "external_pipeline", ExternalJob
         )
         self._solid_handle_id = check.opt_str_param(solid_handle_id, "solid_handle_id")
         super().__init__()
