@@ -1,6 +1,6 @@
 import dagster._check as check
 import graphene
-from dagster._core.host_representation import RepresentedPipeline
+from dagster._core.host_representation import RepresentedJob
 
 from ..errors import (
     GraphenePipelineNotFoundError,
@@ -17,14 +17,14 @@ class GraphenePipelineSnapshot(GrapheneIPipelineSnapshotMixin, graphene.ObjectTy
         interfaces = (GrapheneSolidContainer, GrapheneIPipelineSnapshot, GraphenePipelineReference)
         name = "PipelineSnapshot"
 
-    def __init__(self, represented_pipeline):
+    def __init__(self, represented_job: RepresentedJob):
         super().__init__()
-        self._represented_pipeline = check.inst_param(
-            represented_pipeline, "represented_pipeline", RepresentedPipeline
+        self._represented_job = check.inst_param(
+            represented_job, "represented_pipeline", RepresentedJob
         )
 
-    def get_represented_pipeline(self):
-        return self._represented_pipeline
+    def get_represented_job(self) -> RepresentedJob:
+        return self._represented_job
 
 
 class GraphenePipelineSnapshotOrError(graphene.Union):
