@@ -14,11 +14,17 @@ from dagster._core.definitions.selector import (
 )
 from dagster._core.execution.backfill import BulkActionStatus
 from dagster._core.nux import get_has_seen_nux
-from dagster._core.scheduler.instigation import InstigatorType
+from dagster._core.scheduler.instigation import InstigatorStatus, InstigatorType
 
+from dagster_graphql.implementation.fetch_auto_materialize_asset_evaluations import (
+    fetch_auto_materialize_asset_evaluations,
+)
 from dagster_graphql.implementation.fetch_env_vars import get_utilized_env_vars_or_error
 from dagster_graphql.implementation.fetch_logs import get_captured_log_metadata
 from dagster_graphql.implementation.fetch_runs import get_assets_latest_info
+from dagster_graphql.schema.auto_materialize_asset_evaluations import (
+    GrapheneAutoMaterializeAssetEvaluationRecordsOrError,
+)
 from dagster_graphql.schema.env_vars import GrapheneEnvVarWithConsumersListOrError
 
 from ...implementation.external import (
@@ -41,9 +47,9 @@ from ...implementation.fetch_instigators import (
 )
 from ...implementation.fetch_partition_sets import get_partition_set, get_partition_sets_or_error
 from ...implementation.fetch_pipelines import (
-    get_pipeline_or_error,
-    get_pipeline_snapshot_or_error_from_pipeline_selector,
-    get_pipeline_snapshot_or_error_from_snapshot_id,
+    get_job_or_error,
+    get_job_snapshot_or_error_from_job_selector,
+    get_job_snapshot_or_error_from_snapshot_id,
 )
 from ...implementation.fetch_resources import (
     get_resource_or_error,
@@ -72,7 +78,11 @@ from ...implementation.loader import (
     StaleStatusLoader,
 )
 from ...implementation.run_config_schema import resolve_run_config_schema_or_error
-from ...implementation.utils import graph_selector_from_graphql, pipeline_selector_from_graphql
+from ...implementation.utils import (
+    capture_error,
+    graph_selector_from_graphql,
+    pipeline_selector_from_graphql,
+)
 from ..asset_graph import (
     GrapheneAssetLatestInfo,
     GrapheneAssetNode,
@@ -107,6 +117,7 @@ from ..instance import GrapheneInstance
 from ..instigation import (
     GrapheneInstigationStateOrError,
     GrapheneInstigationStatesOrError,
+    GrapheneInstigationStatus,
     GrapheneInstigationType,
 )
 from ..logs.compute_logs import (
@@ -208,6 +219,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
     schedulesOrError = graphene.Field(
         graphene.NonNull(GrapheneSchedulesOrError),
         repositorySelector=graphene.NonNull(GrapheneRepositorySelector),
+        scheduleStatus=graphene.Argument(GrapheneInstigationStatus),
         description="Retrieve all the schedules.",
     )
 
@@ -240,6 +252,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
     sensorsOrError = graphene.Field(
         graphene.NonNull(GrapheneSensorsOrError),
         repositorySelector=graphene.NonNull(GrapheneRepositorySelector),
+        sensorStatus=graphene.Argument(GrapheneInstigationStatus),
         description="Retrieve all the sensors.",
     )
 
@@ -456,6 +469,15 @@ class GrapheneDagitQuery(graphene.ObjectType):
         description="Provides fields for testing behavior",
     )
 
+    autoMaterializeAssetEvaluationsOrError = graphene.Field(
+        GrapheneAutoMaterializeAssetEvaluationRecordsOrError,
+        assetKey=graphene.Argument(graphene.NonNull(GrapheneAssetKeyInput)),
+        limit=graphene.Argument(graphene.NonNull(graphene.Int)),
+        cursor=graphene.Argument(graphene.String),
+        description="Retrieve the auto materialization evaluation records for all assets.",
+    )
+
+    @capture_error
     def resolve_repositoriesOrError(
         self,
         graphene_info: ResolveInfo,
@@ -472,6 +494,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
             )
         return fetch_repositories(graphene_info)
 
+    @capture_error
     def resolve_repositoryOrError(
         self, graphene_info: ResolveInfo, repositorySelector: GrapheneRepositorySelector
     ):
@@ -479,12 +502,15 @@ class GrapheneDagitQuery(graphene.ObjectType):
             graphene_info, RepositorySelector.from_graphql_input(repositorySelector)
         )
 
+    @capture_error
     def resolve_workspaceOrError(self, graphene_info: ResolveInfo):
         return fetch_workspace(graphene_info.context)
 
+    @capture_error
     def resolve_locationStatusesOrError(self, graphene_info: ResolveInfo):
         return fetch_location_statuses(graphene_info.context)
 
+    @capture_error
     def resolve_pipelineSnapshotOrError(
         self,
         graphene_info: ResolveInfo,
@@ -498,16 +524,15 @@ class GrapheneDagitQuery(graphene.ObjectType):
 
         if activePipelineSelector:
             pipeline_selector = pipeline_selector_from_graphql(activePipelineSelector)
-            return get_pipeline_snapshot_or_error_from_pipeline_selector(
-                graphene_info, pipeline_selector
-            )
+            return get_job_snapshot_or_error_from_job_selector(graphene_info, pipeline_selector)
         elif snapshotId:
-            return get_pipeline_snapshot_or_error_from_snapshot_id(graphene_info, snapshotId)
+            return get_job_snapshot_or_error_from_snapshot_id(graphene_info, snapshotId)
         else:
             check.failed(
                 "Must set one of snapshotId or activePipelineSelector",
             )
 
+    @capture_error
     def resolve_graphOrError(
         self, graphene_info: ResolveInfo, selector: Optional[GrapheneGraphSelector] = None
     ):
@@ -518,9 +543,11 @@ class GrapheneDagitQuery(graphene.ObjectType):
     def resolve_version(self, graphene_info: ResolveInfo):
         return graphene_info.context.version
 
+    @capture_error
     def resolve_scheduler(self, graphene_info: ResolveInfo):
         return get_scheduler_or_error(graphene_info)
 
+    @capture_error
     def resolve_scheduleOrError(
         self, graphene_info: ResolveInfo, schedule_selector: GrapheneScheduleSelector
     ):
@@ -528,14 +555,27 @@ class GrapheneDagitQuery(graphene.ObjectType):
             graphene_info, ScheduleSelector.from_graphql_input(schedule_selector)
         )
 
+    @capture_error
     def resolve_schedulesOrError(
-        self, graphene_info: ResolveInfo, repositorySelector: GrapheneRepositorySelector
+        self,
+        graphene_info: ResolveInfo,
+        repositorySelector: GrapheneRepositorySelector,
+        scheduleStatus: Optional[GrapheneInstigationStatus] = None,
     ):
+        if scheduleStatus == GrapheneInstigationStatus.RUNNING:
+            instigator_statuses = {InstigatorStatus.RUNNING, InstigatorStatus.AUTOMATICALLY_RUNNING}
+        elif scheduleStatus == GrapheneInstigationStatus.STOPPED:
+            instigator_statuses = {InstigatorStatus.STOPPED}
+        else:
+            instigator_statuses = None
+
         return get_schedules_or_error(
             graphene_info,
             RepositorySelector.from_graphql_input(repositorySelector),
+            instigator_statuses,
         )
 
+    @capture_error
     def resolve_topLevelResourceDetailsOrError(self, graphene_info: ResolveInfo, resourceSelector):
         return get_resource_or_error(
             graphene_info, ResourceSelector.from_graphql_input(resourceSelector)
@@ -547,23 +587,39 @@ class GrapheneDagitQuery(graphene.ObjectType):
             RepositorySelector.from_graphql_input(kwargs.get("repositorySelector")),
         )
 
+    @capture_error
     def resolve_utilizedEnvVarsOrError(self, graphene_info: ResolveInfo, **kwargs):
         return get_utilized_env_vars_or_error(
             graphene_info,
             RepositorySelector.from_graphql_input(kwargs.get("repositorySelector")),
         )
 
+    @capture_error
     def resolve_sensorOrError(
         self, graphene_info: ResolveInfo, sensorSelector: GrapheneRepositorySelector
     ):
         return get_sensor_or_error(graphene_info, SensorSelector.from_graphql_input(sensorSelector))
 
-    def resolve_sensorsOrError(self, graphene_info, repositorySelector: GrapheneRepositorySelector):
+    @capture_error
+    def resolve_sensorsOrError(
+        self,
+        graphene_info,
+        repositorySelector: GrapheneRepositorySelector,
+        sensorStatus: Optional[GrapheneInstigationStatus] = None,
+    ):
+        if sensorStatus == GrapheneInstigationStatus.RUNNING:
+            instigator_statuses = {InstigatorStatus.RUNNING, InstigatorStatus.AUTOMATICALLY_RUNNING}
+        elif sensorStatus == GrapheneInstigationStatus.STOPPED:
+            instigator_statuses = {InstigatorStatus.STOPPED}
+        else:
+            instigator_statuses = None
         return get_sensors_or_error(
             graphene_info,
             RepositorySelector.from_graphql_input(repositorySelector),
+            instigator_statuses,
         )
 
+    @capture_error
     def resolve_instigationStateOrError(
         self, graphene_info: ResolveInfo, instigationSelector: GrapheneInstigationSelector
     ):
@@ -571,14 +627,16 @@ class GrapheneDagitQuery(graphene.ObjectType):
             graphene_info, InstigatorSelector.from_graphql_input(instigationSelector)
         )
 
+    @capture_error
     def resolve_unloadableInstigationStatesOrError(
         self, graphene_info: ResolveInfo, instigationType: Optional[GrapheneInstigationType] = None
     ):
         instigation_type = InstigatorType(instigationType) if instigationType else None
         return get_unloadable_instigator_states_or_error(graphene_info, instigation_type)
 
+    @capture_error
     def resolve_pipelineOrError(self, graphene_info: ResolveInfo, params: GraphenePipelineSelector):
-        return get_pipeline_or_error(
+        return get_job_or_error(
             graphene_info,
             pipeline_selector_from_graphql(params),
         )
@@ -632,6 +690,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
             results=get_run_groups(graphene_info, selector, cursor, limit)
         )
 
+    @capture_error
     def resolve_partitionSetsOrError(
         self, graphene_info: ResolveInfo, repositorySelector: RepositorySelector, pipelineName: str
     ):
@@ -641,6 +700,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
             pipelineName,
         )
 
+    @capture_error
     def resolve_partitionSetOrError(
         self,
         graphene_info: ResolveInfo,
@@ -654,9 +714,11 @@ class GrapheneDagitQuery(graphene.ObjectType):
             partitionSetName,  # type: ignore
         )
 
+    @capture_error
     def resolve_runTagKeysOrError(self, graphene_info: ResolveInfo):
         return get_run_tag_keys(graphene_info)
 
+    @capture_error
     def resolve_runTagsOrError(
         self,
         graphene_info: ResolveInfo,
@@ -666,9 +728,11 @@ class GrapheneDagitQuery(graphene.ObjectType):
     ):
         return get_run_tags(graphene_info, tagKeys, valuePrefix, limit)
 
+    @capture_error
     def resolve_runGroupOrError(self, graphene_info: ResolveInfo, runId):
         return get_run_group(graphene_info, runId)
 
+    @capture_error
     def resolve_isPipelineConfigValid(
         self,
         graphene_info: ResolveInfo,
@@ -680,9 +744,9 @@ class GrapheneDagitQuery(graphene.ObjectType):
             graphene_info,
             pipeline_selector_from_graphql(pipeline),
             parse_run_config_input(runConfigData or {}, raise_on_error=False),
-            mode,
         )
 
+    @capture_error
     def resolve_executionPlanOrError(
         self,
         graphene_info: ResolveInfo,
@@ -694,9 +758,9 @@ class GrapheneDagitQuery(graphene.ObjectType):
             graphene_info,
             pipeline_selector_from_graphql(pipeline),
             parse_run_config_input(runConfigData or {}, raise_on_error=True),  # type: ignore  # (possible str)
-            mode,
         )
 
+    @capture_error
     def resolve_runConfigSchemaOrError(
         self,
         graphene_info: ResolveInfo,
@@ -704,9 +768,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
         mode: Optional[str] = None,
     ):
         return resolve_run_config_schema_or_error(
-            graphene_info,
-            pipeline_selector_from_graphql(selector),
-            mode,
+            graphene_info, pipeline_selector_from_graphql(selector), mode
         )
 
     def resolve_instance(self, graphene_info: ResolveInfo):
@@ -720,10 +782,16 @@ class GrapheneDagitQuery(graphene.ObjectType):
         pipeline: Optional[GraphenePipelineSelector] = None,
         assetKeys: Optional[Sequence[GrapheneAssetKeyInput]] = None,
     ) -> Sequence[GrapheneAssetNode]:
-        resolved_asset_keys = set(
-            AssetKey.from_graphql_input(asset_key_input) for asset_key_input in assetKeys or []
-        )
-        use_all_asset_keys = len(resolved_asset_keys) == 0
+        if assetKeys == []:
+            return []
+        elif not assetKeys:
+            use_all_asset_keys = True
+            resolved_asset_keys = None
+        else:
+            use_all_asset_keys = False
+            resolved_asset_keys = set(
+                AssetKey.from_graphql_input(asset_key_input) for asset_key_input in assetKeys or []
+            )
 
         repo = None
 
@@ -749,11 +817,11 @@ class GrapheneDagitQuery(graphene.ObjectType):
                 else []
             )
         elif pipeline is not None:
-            pipeline_name = pipeline.pipelineName
+            job_name = pipeline.pipelineName
             repo_sel = RepositorySelector.from_graphql_input(pipeline)
             repo_loc = graphene_info.context.get_code_location(repo_sel.location_name)
             repo = repo_loc.get_repository(repo_sel.repository_name)
-            external_asset_nodes = repo.get_external_asset_nodes(pipeline_name)
+            external_asset_nodes = repo.get_external_asset_nodes(job_name)
             results = (
                 [
                     GrapheneAssetNode(
@@ -772,7 +840,9 @@ class GrapheneDagitQuery(graphene.ObjectType):
 
         # Filter down to requested asset keys
         results = [
-            node for node in results if use_all_asset_keys or node.assetKey in resolved_asset_keys
+            node
+            for node in results
+            if use_all_asset_keys or node.assetKey in check.not_none(resolved_asset_keys)
         ]
 
         if not results:
@@ -813,6 +883,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
         asset_key_input = cast(Mapping[str, Sequence[str]], assetKey)
         return get_asset_node(graphene_info, AssetKey.from_graphql_input(asset_key_input))
 
+    @capture_error
     def resolve_assetsOrError(
         self,
         graphene_info: ResolveInfo,
@@ -840,9 +911,11 @@ class GrapheneDagitQuery(graphene.ObjectType):
         asset_keys = set(AssetKey.from_graphql_input(asset_key) for asset_key in raw_asset_keys)
         return get_asset_node_definition_collisions(graphene_info, asset_keys)
 
+    @capture_error
     def resolve_partitionBackfillOrError(self, graphene_info: ResolveInfo, backfillId: str):
         return get_backfill(graphene_info, backfillId)
 
+    @capture_error
     def resolve_partitionBackfillsOrError(
         self,
         graphene_info: ResolveInfo,
@@ -878,6 +951,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
 
         return get_assets_latest_info(graphene_info, step_keys_by_asset)
 
+    @capture_error
     def resolve_logsForRun(
         self,
         graphene_info: ResolveInfo,
@@ -912,3 +986,14 @@ class GrapheneDagitQuery(graphene.ObjectType):
 
     def resolve_test(self, _):
         return GrapheneTestFields()
+
+    def resolve_autoMaterializeAssetEvaluationsOrError(
+        self,
+        graphene_info: ResolveInfo,
+        assetKey: GrapheneAssetKeyInput,
+        limit: int,
+        cursor: Optional[str] = None,
+    ):
+        return fetch_auto_materialize_asset_evaluations(
+            graphene_info=graphene_info, graphene_asset_key=assetKey, cursor=cursor, limit=limit
+        )
